@@ -89,20 +89,38 @@ class TaskProcedure extends BaseProcedure
         return $this->taskProjectDuplicationModel->duplicateToProject($task_id, $project_id, $swimlane_id, $column_id, $category_id, $owner_id);
     }
 
-    public function createTask($title, $project_id, $color_id = '', $column_id = 0, $owner_id = 0, $creator_id = 0,
-                               $date_due = '', $description = '', $category_id = 0, $score = 0, $swimlane_id = null, $priority = 0,
-                               $recurrence_status = 0, $recurrence_trigger = 0, $recurrence_factor = 0, $recurrence_timeframe = 0,
-                               $recurrence_basedate = 0, $reference = '', array $tags = array(), $date_started = '',
-                               $time_spent = null, $time_estimated = null)
-    {
+    public function createTask(
+        $title,
+        $project_id,
+        $color_id = '',
+        $column_id = 0,
+        $owner_id = 0,
+        $creator_id = 0,
+        $date_due = '',
+        $description = '',
+        $category_id = 0,
+        $score = 0,
+        $swimlane_id = null,
+        $priority = 0,
+        $recurrence_status = 0,
+        $recurrence_trigger = 0,
+        $recurrence_factor = 0,
+        $recurrence_timeframe = 0,
+        $recurrence_basedate = 0,
+        $reference = '',
+        array $tags = array(),
+        $date_started = '',
+        $time_spent = null,
+        $time_estimated = null
+    ) {
         ProjectAuthorization::getInstance($this->container)->check($this->getClassName(), 'createTask', $project_id);
 
         if ($owner_id !== 0 && ! $this->projectPermissionModel->isAssignable($project_id, $owner_id)) {
             return false;
         }
 
-        if ($this->userSession->isLogged()) {
-            $creator_id = $this->userSession->getId();
+        if ($creator_id !== 0 && ! $this->projectPermissionModel->isAssignable($project_id, $creator_id)) {
+            return false;
         }
 
         $values = array(
@@ -135,12 +153,27 @@ class TaskProcedure extends BaseProcedure
         return $valid ? $this->taskCreationModel->create($values) : false;
     }
 
-    public function updateTask($id, $title = null, $color_id = null, $owner_id = null,
-                               $date_due = null, $description = null, $category_id = null, $score = null, $priority = null,
-                               $recurrence_status = null, $recurrence_trigger = null, $recurrence_factor = null,
-                               $recurrence_timeframe = null, $recurrence_basedate = null, $reference = null, $tags = null, $date_started = null,
-                               $time_spent = null, $time_estimated = null)
-    {
+    public function updateTask(
+        $id,
+        $title = null,
+        $color_id = null,
+        $owner_id = null,
+        $date_due = null,
+        $description = null,
+        $category_id = null,
+        $score = null,
+        $priority = null,
+        $recurrence_status = null,
+        $recurrence_trigger = null,
+        $recurrence_factor = null,
+        $recurrence_timeframe = null,
+        $recurrence_basedate = null,
+        $reference = null,
+        $tags = null,
+        $date_started = null,
+        $time_spent = null,
+        $time_estimated = null
+    ) {
         TaskAuthorization::getInstance($this->container)->check($this->getClassName(), 'updateTask', $id);
         $project_id = $this->taskFinderModel->getProjectId($id);
 
