@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => '.',
     'None' => 'None',
@@ -525,11 +525,11 @@ return array(
     'INR - Indian Rupee' => 'INR - Indijski rupi',
     'JPY - Japanese Yen' => 'JPY - Japanski jen',
     'NZD - New Zealand Dollar' => 'NZD - Novozelandski dolar',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - Peruanski sol',
     'RSD - Serbian dinar' => 'RSD - Srpski dinar',
-    // 'CNY - Chinese Yuan' => '',
+    'CNY - Chinese Yuan' => 'CNY - Kineski juan',
     'USD - US Dollar' => 'USD - Američki dolar',
-    // 'VES - Venezuelan Bolívar' => '',
+    'VES - Venezuelan Bolívar' => 'VES - Venecuelanski bolivar',
     'Destination column' => 'Odredišna kolona',
     'Move the task to another column when assigned to a user' => 'Premjesti zadatak u neku drugu kolonu kada se dodijeli izvršiocu',
     'Move the task to another column when assignee is cleared' => 'Premjesti zadatak u neku drugu kolonu kada se ukloni izvršilac',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Swimlane traka promijenjena za zadatak #%d',
     'Assignee changed on task #%d' => 'Promijenjen izvršilac na zadatku #%d',
     '%d overdue tasks' => '%d zadataka kasni',
-    'Task #%d is overdue' => 'Zadatak #%d kasni',
     'No notification.' => 'Nema novih obavještenja.',
     'Mark all as read' => 'Označi sve kao pročitano',
     'Mark as read' => 'Označi kao pročitano',
@@ -1082,7 +1081,7 @@ return array(
     'Email settings' => 'Postavke email-a',
     'Email sender address' => 'Email adresa pošiljaoca',
     'Email transport' => 'Saobraćaj emil-a',
-    // 'Webhook token' => '',
+    'Webhook token' => 'Webhook token',
     'Project tags management' => 'Upravljanje oznakama projekta',
     'Tag created successfully.' => 'Oznaka uspješno kreirana.',
     'Unable to create this tag.' => 'Nemoguće kreirati oznaku.',
@@ -1286,184 +1285,187 @@ return array(
     'Assign automatically a color when due date is expired' => 'Automatski dodaj boju kada je krajnje vrijeme izvršenja isteklo',
     'Total score in this column across all swimlanes' => 'Ukupni rezultat u ovoj koloni za sve swimlane trake',
     'HRK - Kuna' => 'HRK - Hrvatska Kuna',
-    // 'ARS - Argentine Peso' => '',
-    // 'COP - Colombian Peso' => '',
-    // '%d groups' => '',
-    // '%d group' => '',
-    // 'Group ID' => '',
-    // 'External ID' => '',
-    // '%d users' => '',
-    // '%d user' => '',
-    // 'Hide subtasks' => '',
-    // 'Show subtasks' => '',
-    // 'Authentication Parameters' => '',
-    // 'API Access' => '',
-    // 'No users found.' => '',
-    // 'User ID' => '',
-    // 'Notifications are activated' => '',
-    // 'Notifications are disabled' => '',
-    // 'User disabled' => '',
-    // '%d notifications' => '',
-    // '%d notification' => '',
-    // 'There is no external integration installed.' => '',
-    // 'You are not allowed to update tasks assigned to someone else.' => '',
-    // 'You are not allowed to change the assignee.' => '',
-    // 'Task suppression is not permitted' => '',
-    // 'Changing assignee is not permitted' => '',
-    // 'Update only assigned tasks is permitted' => '',
-    // 'Only for tasks assigned to the current user' => '',
-    // 'My projects' => '',
-    // 'You are not a member of any project.' => '',
-    // 'My subtasks' => '',
-    // '%d subtasks' => '',
-    // '%d subtask' => '',
-    // 'Only moving task between those columns is permitted for tasks assigned to the current user' => '',
-    // '[DUPLICATE]' => '',
-    // 'DKK - Danish Krona' => '',
-    // 'Remove user from group' => '',
-    // 'Assign the task to its creator' => '',
-    // 'This task was sent by email to "%s" with subject "%s".' => '',
-    // 'Predefined Email Subjects' => '',
-    // 'Write one subject by line.' => '',
-    // 'Create another link' => '',
-    // 'BRL - Brazilian Real' => '',
-    // 'Add a new Kanboard task' => '',
-    // 'Subtask not started' => '',
-    // 'Subtask currently in progress' => '',
-    // 'Subtask completed' => '',
-    // 'Subtask added successfully.' => '',
-    // '%d subtasks added successfully.' => '',
-    // 'Enter one subtask by line.' => '',
-    // 'Predefined Contents' => '',
-    // 'Predefined contents' => '',
-    // 'Predefined Task Description' => '',
-    // 'Do you really want to remove this template? "%s"' => '',
-    // 'Add predefined task description' => '',
-    // 'Predefined Task Descriptions' => '',
-    // 'Template created successfully.' => '',
-    // 'Unable to create this template.' => '',
-    // 'Template updated successfully.' => '',
-    // 'Unable to update this template.' => '',
-    // 'Template removed successfully.' => '',
-    // 'Unable to remove this template.' => '',
-    // 'Template for the task description' => '',
-    // 'The start date is greater than the end date' => '',
-    // 'Tags must be separated by a comma' => '',
-    // 'Only the task title is required' => '',
-    // 'Creator Username' => '',
-    // 'Color Name' => '',
-    // 'Column Name' => '',
-    // 'Swimlane Name' => '',
-    // 'Time Estimated' => '',
-    // 'Time Spent' => '',
-    // 'External Link' => '',
-    // 'This feature enables the iCal feed, RSS feed and the public board view.' => '',
-    // 'Stop the timer of all subtasks when moving a task to another column' => '',
-    // 'Subtask Title' => '',
-    // 'Add a subtask and activate the timer when moving a task to another column' => '',
-    // 'days' => '',
-    // 'minutes' => '',
-    // 'seconds' => '',
-    // 'Assign automatically a color when preset start date is reached' => '',
-    // 'Move the task to another column once a predefined start date is reached' => '',
-    // 'This task is now linked to the task %s with the relation "%s"' => '',
-    // 'The link with the relation "%s" to the task %s has been removed' => '',
-    // 'Custom Filter:' => '',
-    // 'Unable to find this group.' => '',
-    // '%s moved the task #%d to the column "%s"' => '',
-    // '%s moved the task #%d to the position %d in the column "%s"' => '',
-    // '%s moved the task #%d to the swimlane "%s"' => '',
-    // '%sh spent' => '',
-    // '%sh estimated' => '',
-    // 'Select All' => '',
-    // 'Unselect All' => '',
-    // 'Apply action' => '',
-    // 'Move selected tasks to another column or swimlane' => '',
-    // 'Edit tasks in bulk' => '',
-    // 'Choose the properties that you would like to change for the selected tasks.' => '',
-    // 'Configure this project' => '',
-    // 'Start now' => '',
-    // '%s removed a file from the task #%d' => '',
-    // 'Attachment removed from task #%d: %s' => '',
-    // 'No color' => '',
-    // 'Attachment removed "%s"' => '',
-    // '%s removed a file from the task %s' => '',
-    // 'Move the task to another swimlane when assigned to a user' => '',
-    // 'Destination swimlane' => '',
-    // 'Assign a category when the task is moved to a specific swimlane' => '',
-    // 'Move the task to another swimlane when the category is changed' => '',
-    // 'Reorder this column by priority (ASC)' => '',
-    // 'Reorder this column by priority (DESC)' => '',
-    // 'Reorder this column by assignee and priority (ASC)' => '',
-    // 'Reorder this column by assignee and priority (DESC)' => '',
-    // 'Reorder this column by assignee (A-Z)' => '',
-    // 'Reorder this column by assignee (Z-A)' => '',
-    // 'Reorder this column by due date (ASC)' => '',
-    // 'Reorder this column by due date (DESC)' => '',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
-    // '%s moved the task #%d "%s" to the project "%s"' => '',
-    // 'Task #%d "%s" has been moved to the project "%s"' => '',
-    // 'Move the task to another column when the due date is less than a certain number of days' => '',
-    // 'Automatically update the start date when the task is moved away from a specific column' => '',
-    // 'HTTP Client:' => '',
-    // 'Assigned' => '',
-    // 'Task limits apply to each swimlane individually' => '',
-    // 'Column task limits apply to each swimlane individually' => '',
-    // 'Column task limits are applied to each swimlane individually' => '',
-    // 'Column task limits are applied across swimlanes' => '',
-    // 'Task limit: ' => '',
-    // 'Change to global tag' => '',
-    // 'Do you really want to make the tag "%s" global?' => '',
-    // 'Enable global tags for this project' => '',
-    // 'Group membership(s):' => '',
-    // '%s is a member of the following group(s): %s' => '',
-    // '%d/%d group(s) shown' => '',
-    // 'Subtask creation or modification' => '',
-    // 'Assign the task to a specific user when the task is moved to a specific swimlane' => '',
-    // 'Comment' => '',
-    // 'Collapse vertically' => '',
-    // 'Expand vertically' => '',
-    // 'MXN - Mexican Peso' => '',
-    // 'Estimated vs actual time per column' => '',
-    // 'HUF - Hungarian Forint' => '',
-    // 'XBT - Bitcoin' => '',
-    // 'You must select a file to upload as your avatar!' => '',
-    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'ARS - Argentine Peso' => 'ARS - Argentinski pezo',
+    'COP - Colombian Peso' => 'COP - Kolumbijski pezo',
+    '%d groups' => '%d grupa',
+    '%d group' => '%d grupa',
+    'Group ID' => 'ID grupe',
+    'External ID' => 'Vanjski ID',
+    '%d users' => '%d korisnika',
+    '%d user' => '%d korisnik',
+    'Hide subtasks' => 'Sakrij pod-zadatke',
+    'Show subtasks' => 'Prikaži pod-zadatke',
+    'Authentication Parameters' => 'Parametri autentifikacije',
+    'API Access' => 'API pristup',
+    'No users found.' => 'Nema pronađenih korisnika.',
+    'User ID' => 'ID korisnika',
+    'Notifications are activated' => 'Obavještenja su aktivirana',
+    'Notifications are disabled' => 'Obavještenja su onemogućena',
+    'User disabled' => 'Korisnik onemogućen',
+    '%d notifications' => '%d obavještenja',
+    '%d notification' => '%d obavještenje',
+    'There is no external integration installed.' => 'Nema instaliranih vanjskih integracija.',
+    'You are not allowed to update tasks assigned to someone else.' => 'Nemaš dozvolu za ažuriranje zadataka dodijeljenih drugima.',
+    'You are not allowed to change the assignee.' => 'Nemaš dozvolu za promjenu izvršioca.',
+    'Task suppression is not permitted' => 'Brisanje zadatka nije dozvoljeno',
+    'Changing assignee is not permitted' => 'Promjena izvršioca nije dozvoljena',
+    'Update only assigned tasks is permitted' => 'Ažuriranje samo dodijeljenih zadataka je dozvoljeno',
+    'Only for tasks assigned to the current user' => 'Samo za zadatke dodijeljene trenutnom korisniku',
+    'My projects' => 'Moji projekti',
+    'You are not a member of any project.' => 'Nisi član ni jednog projekta.',
+    'My subtasks' => 'Moji pod-zadaci',
+    '%d subtasks' => '%d pod-zadataka',
+    '%d subtask' => '%d pod-zadatak',
+    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Pomijeranje zadataka između ovih kolona je dozvoljeno samo za zadatke dodijeljene trenutnom korisniku',
+    '[DUPLICATE]' => '[DUPLIKAT]',
+    'DKK - Danish Krona' => 'DKK - Danska kruna',
+    'Remove user from group' => 'Ukloni korisnika iz grupe',
+    'Assign the task to its creator' => 'Dodijeli zadatak njegovom kreatoru',
+    'This task was sent by email to "%s" with subject "%s".' => 'Ovaj zadatak je poslan email-om "%s" sa predmetom "%s".',
+    'Predefined Email Subjects' => 'Predefinisani predmeti email-a',
+    'Write one subject by line.' => 'Napiši jedan predmet po liniji.',
+    'Create another link' => 'Kreiraj drugu vezu',
+    'BRL - Brazilian Real' => 'BRL - Brazilski real',
+    'Add a new Kanboard task' => 'Dodaj novi Kanboard zadatak',
+    'Subtask not started' => 'Pod-zadatak nije započet',
+    'Subtask currently in progress' => 'Pod-zadatak trenutno u toku',
+    'Subtask completed' => 'Pod-zadatak završen',
+    'Subtask added successfully.' => 'Pod-zadatak uspješno dodan.',
+    '%d subtasks added successfully.' => '%d pod-zadataka uspješno dodano.',
+    'Enter one subtask by line.' => 'Unesi jedan pod-zadatak po liniji.',
+    'Predefined Contents' => 'Predefinisani sadržaji',
+    'Predefined contents' => 'Predefinisani sadržaji',
+    'Predefined Task Description' => 'Predefinisani opis zadatka',
+    'Do you really want to remove this template? "%s"' => 'Da li zaista želiš ukloniti ovaj šablon? "%s"',
+    'Add predefined task description' => 'Dodaj predefinisani opis zadatka',
+    'Predefined Task Descriptions' => 'Predefinisani opisi zadataka',
+    'Template created successfully.' => 'Šablon uspješno kreiran.',
+    'Unable to create this template.' => 'Nemoguće kreirati ovaj šablon.',
+    'Template updated successfully.' => 'Šablon uspješno ažuriran.',
+    'Unable to update this template.' => 'Nemoguće ažurirati ovaj šablon.',
+    'Template removed successfully.' => 'Šablon uspješno uklonjen.',
+    'Unable to remove this template.' => 'Nemoguće ukloniti ovaj šablon.',
+    'Template for the task description' => 'Šablon za opis zadatka',
+    'The start date is greater than the end date' => 'Početni datum je veći od krajnjeg datuma',
+    'Tags must be separated by a comma' => 'Oznake moraju biti odvojene zarezom',
+    'Only the task title is required' => 'Samo je naslov zadatka obavezan',
+    'Creator Username' => 'Korisničko ime kreatora',
+    'Color Name' => 'Naziv boje',
+    'Column Name' => 'Naziv kolone',
+    'Swimlane Name' => 'Naziv swimlane trake',
+    'Time Estimated' => 'Procijenjeno vrijeme',
+    'Time Spent' => 'Utrošeno vrijeme',
+    'External Link' => 'Vanjska veza',
+    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Ova funkcionalnost omogućava iCal feed, RSS feed i javni pregled ploče.',
+    'Stop the timer of all subtasks when moving a task to another column' => 'Zaustavi tajmer svih pod-zadataka kada se zadatak premjesti u drugu kolonu',
+    'Subtask Title' => 'Naslov pod-zadatka',
+    'Add a subtask and activate the timer when moving a task to another column' => 'Dodaj pod-zadatak i aktiviraj tajmer kada se zadatak premjesti u drugu kolonu',
+    'days' => 'dana',
+    'minutes' => 'minuta',
+    'seconds' => 'sekundi',
+    'Assign automatically a color when preset start date is reached' => 'Automatski dodijeli boju kada se dostigne unaprijed postavljeni početni datum',
+    'Move the task to another column once a predefined start date is reached' => 'Premjesti zadatak u drugu kolonu kada se dostigne unaprijed postavljeni početni datum',
+    'This task is now linked to the task %s with the relation "%s"' => 'Ovaj zadatak je sada povezan sa zadatkom %s sa relacijom "%s"',
+    'The link with the relation "%s" to the task %s has been removed' => 'Veza sa relacijom "%s" prema zadatku %s je uklonjena',
+    'Custom Filter:' => 'Prilagođeni filter:',
+    'Unable to find this group.' => 'Nemoguće pronaći ovu grupu.',
+    '%s moved the task #%d to the column "%s"' => '%s je premjestio zadatak #%d u kolonu "%s"',
+    '%s moved the task #%d to the position %d in the column "%s"' => '%s je premjestio zadatak #%d na poziciju %d u koloni "%s"',
+    '%s moved the task #%d to the swimlane "%s"' => '%s je premjestio zadatak #%d u swimlane traku "%s"',
+    '%sh spent' => '%sh utrošeno',
+    '%sh estimated' => '%sh procijenjeno',
+    'Select All' => 'Označi sve',
+    'Unselect All' => 'Poništi sve',
+    'Apply action' => 'Primijeni akciju',
+    'Move selected tasks to another column or swimlane' => 'Premjesti odabrane zadatke u drugu kolonu ili swimlane traku',
+    'Edit tasks in bulk' => 'Uredi zadatke u rinfuzi',
+    'Choose the properties that you would like to change for the selected tasks.' => 'Izaberi svojstva koja želiš promijeniti za odabrane zadatke.',
+    'Configure this project' => 'Konfiguriši ovaj projekat',
+    'Start now' => 'Počni sada',
+    '%s removed a file from the task #%d' => '%s je uklonio datoteku sa zadatka #%d',
+    'Attachment removed from task #%d: %s' => 'Prilog uklonjen sa zadatka #%d: %s',
+    'No color' => 'Bez boje',
+    'Attachment removed "%s"' => 'Prilog uklonjen "%s"',
+    '%s removed a file from the task %s' => '%s je uklonio datoteku sa zadatka %s',
+    'Move the task to another swimlane when assigned to a user' => 'Premjesti zadatak u drugu swimlane traku kada je dodijeljen korisniku',
+    'Destination swimlane' => 'Odredišna swimlane traka',
+    'Assign a category when the task is moved to a specific swimlane' => 'Dodijeli kategoriju kada je zadatak premješten u određenu swimlane traku',
+    'Move the task to another swimlane when the category is changed' => 'Premjesti zadatak u drugu swimlane traku kada je kategorija promijenjena',
+    'Reorder this column by priority (ASC)' => 'Presortiraj ovu kolonu po prioritetu (ASC)',
+    'Reorder this column by priority (DESC)' => 'Presortiraj ovu kolonu po prioritetu (DESC)',
+    'Reorder this column by assignee and priority (ASC)' => 'Presortiraj ovu kolonu po izvršiocu i prioritetu (ASC)',
+    'Reorder this column by assignee and priority (DESC)' => 'Presortiraj ovu kolonu po izvršiocu i prioritetu (DESC)',
+    'Reorder this column by assignee (A-Z)' => 'Presortiraj ovu kolonu po izvršiocu (A-Z)',
+    'Reorder this column by assignee (Z-A)' => 'Presortiraj ovu kolonu po izvršiocu (Z-A)',
+    'Reorder this column by due date (ASC)' => 'Presortiraj ovu kolonu po datumu završetka (ASC)',
+    'Reorder this column by due date (DESC)' => 'Presortiraj ovu kolonu po datumu završetka (DESC)',
+    'Reorder this column by id (ASC)' => 'Presortiraj ovu kolonu po ID-u (ASC)',
+    'Reorder this column by id (DESC)' => 'Presortiraj ovu kolonu po ID-u (DESC)',
+    '%s moved the task #%d "%s" to the project "%s"' => '%s je premjestio zadatak #%d "%s" u projekat "%s"',
+    'Task #%d "%s" has been moved to the project "%s"' => 'Zadatak #%d "%s" je premješten u projekat "%s"',
+    'Move the task to another column when the due date is less than a certain number of days' => 'Premjesti zadatak u drugu kolonu kada je datum završetka manji od određenog broja dana',
+    'Automatically update the start date when the task is moved away from a specific column' => 'Automatski ažuriraj početni datum kada je zadatak premješten iz određene kolone',
+    'HTTP Client:' => 'HTTP klijent:',
+    'Assigned' => 'Dodijeljen',
+    'Task limits apply to each swimlane individually' => 'Ograničenja zadataka se primjenjuju na svaku swimlane traku pojedinačno',
+    'Column task limits apply to each swimlane individually' => 'Ograničenja zadataka u koloni se primjenjuju na svaku swimlane traku pojedinačno',
+    'Column task limits are applied to each swimlane individually' => 'Ograničenja zadataka u koloni se primjenjuju na svaku swimlane traku pojedinačno',
+    'Column task limits are applied across swimlanes' => 'Ograničenja zadataka u koloni se primjenjuju na sve swimlane trake',
+    'Task limit: ' => 'Ograničenje zadatka: ',
+    'Change to global tag' => 'Promijeni u globalnu oznaku',
+    'Do you really want to make the tag "%s" global?' => 'Da li zaista želiš učiniti oznaku "%s" globalnom?',
+    'Enable global tags for this project' => 'Omogući globalne oznake za ovaj projekat',
+    'Group membership(s):' => 'Članstvo u grupi:',
+    '%s is a member of the following group(s): %s' => '%s je član sljedećih grupa: %s',
+    '%d/%d group(s) shown' => '%d/%d grupa prikazano',
+    'Subtask creation or modification' => 'Kreiranje ili izmjena pod-zadatka',
+    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Dodijeli zadatak određenom korisniku kada je zadatak premješten u određenu swimlane traku',
+    'Comment' => 'Komentar',
+    'Collapse vertically' => 'Skupi vertikalno',
+    'Expand vertically' => 'Proširi vertikalno',
+    'MXN - Mexican Peso' => 'MXN - Meksički pezo',
+    'Estimated vs actual time per column' => 'Procijenjeno naspram stvarnog vremena po koloni',
+    'HUF - Hungarian Forint' => 'HUF - Mađarski forint',
+    'XBT - Bitcoin' => 'XBT - Bitcoin',
+    'You must select a file to upload as your avatar!' => 'Morate odabrati datoteku za otpremanje kao svoj avatar!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Datoteka koju ste otpremili nije važeća slika! (Dozvoljeni su samo *.gif, *.jpg, *.jpeg i *.png!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Automatski postavi rok kada se zadatak premjesti iz određene kolone',
+    'No other projects found.' => 'Nema pronađenih drugih projekata.',
+    'Tasks copied successfully.' => 'Zadaci su uspješno kopirani.',
+    'Unable to copy tasks.' => 'Nije moguće kopirati zadatke.',
+    'Theme' => 'Tema',
+    'Theme:' => 'Tema:',
+    'Light theme' => 'Svijetla tema',
+    'Dark theme' => 'Tamna tema',
+    'Automatic theme - Sync with system' => 'Automatska tema - Sinhronizacija sa sistemom',
+    'Application managers or more' => 'Menadžeri aplikacije ili više',
+    'Administrators' => 'Administratori',
+    'Visibility:' => 'Vidljivost:',
+    'Standard users' => 'Standardni korisnici',
+    'Visibility is required' => 'Vidljivost je obavezna',
+    'The visibility should be an app role' => 'Vidljivost treba biti uloga aplikacije',
+    'Reply' => 'Odgovori',
+    '%s wrote: ' => '%s je napisao: ',
+    'Number of visible tasks in this column and swimlane' => 'Broj vidljivih zadataka u ovoj koloni i plivačkoj stazi',
+    'Number of tasks in this swimlane' => 'Broj zadataka u ovoj plivačkoj stazi',
+    'Unable to find another subtask in progress, you can close this window.' => 'Nije moguće pronaći drugu podzadatak u toku, možete zatvoriti ovaj prozor.',
+    'This theme is invalid' => 'Ova tema nije važeća',
+    'This role is invalid' => 'Ova uloga nije važeća',
+    'This timezone is invalid' => 'Ova vremenska zona nije važeća',
+    'This language is invalid' => 'Ovaj jezik nije važeći',
+    'This URL is invalid' => 'Ovaj URL nije važeći',
+    'Date format invalid' => 'Nevažeći format datuma',
+    'Time format invalid' => 'Nevažeći format vremena',
+    'Invalid Mail transport' => 'Nevažeći mail transport',
+    'Color invalid' => 'Nevažeća boja',
+    'This value must be greater or equal to %d' => 'Ova vrijednost mora biti veća ili jednaka %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Dodajte BOM na početak datoteke (potrebno za Microsoft Excel)',
+    'Just add these tag(s)' => 'Dodajte samo ove oznake',
+    'Remove internal link(s)' => 'Uklonite interne veze',
+    'Import tasks from another project' => 'Uvezite zadatke iz drugog projekta',
+    'Select the project to copy tasks from' => 'Odaberite projekat iz kojeg želite kopirati zadatke',
+    'The total maximum allowed attachments size is %sB.' => 'Ukupna maksimalna dozvoljena veličina priloga je %sB.',
+    'Add attachments' => 'Dodajte priloge',
+    'Task #%d "%s" is overdue' => 'Zadatak #%d "%s" je s iztečen сроком',
+    'Enable notifications by default for all new users' => 'Omogući obavještenja po difoltu za sve nove korisnike',
+];
