@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => '.',
     'None' => 'Žádné',
@@ -525,7 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Indická rupie',
     'JPY - Japanese Yen' => 'JPY - Japonský jen',
     'NZD - New Zealand Dollar' => 'NZD - Novozélandský dolar',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - Peruánský sol',
     'RSD - Serbian dinar' => 'RSD - Srbský dinár',
     'CNY - Chinese Yuan' => 'CNY - čínský jüan',
     'USD - US Dollar' => 'USD - Americký dolar',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Dráha úkolu #%d byla změněna',
     'Assignee changed on task #%d' => 'Vlastník úkolu #%d byl změněn',
     '%d overdue tasks' => '%d úkolů po datu splnění',
-    'Task #%d is overdue' => 'Úkol #%d je po datu splnění',
     'No notification.' => 'Žádná notifikace.',
     'Mark all as read' => 'Označit vše jako přečtené',
     'Mark as read' => 'Označit jako přečtené',
@@ -1400,8 +1399,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Změnit pořadí tohoto sloupce podle zadavatele (Z-A)',
     'Reorder this column by due date (ASC)' => 'Změnit pořadí tohoto sloupce podle data vypršení platnosti (vzestupně)',
     'Reorder this column by due date (DESC)' => 'Změnit pořadí tohoto sloupce podle data vypršení platnosti (sestupně)',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => 'Přerovnat tento sloupec podle ID (vzestupně)',
+    'Reorder this column by id (DESC)' => 'Přerovnat tento sloupec podle ID (sestupně)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s přesunul úkol #%d "%s" do projektu "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Úkol #%d "%s" byl přesunut do projektu "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Pokud je datum vypršení platnosti menší než určitý počet dní, přesuňte úlohu do jiného sloupce',
@@ -1424,46 +1423,49 @@ return array(
     'Comment' => 'Komentář',
     'Collapse vertically' => 'Rozbalit svisle',
     'Expand vertically' => 'Sbalit svisle',
-    // 'MXN - Mexican Peso' => '',
-    // 'Estimated vs actual time per column' => '',
-    // 'HUF - Hungarian Forint' => '',
+    'MXN - Mexican Peso' => 'MXN - Mexické peso',
+    'Estimated vs actual time per column' => 'Odhadovaný vs. skutečný čas na sloupec',
+    'HUF - Hungarian Forint' => 'HUF - Maďarský forint',
     'XBT - Bitcoin' => 'XBT - Bitcoin',
-    // 'You must select a file to upload as your avatar!' => '',
-    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'You must select a file to upload as your avatar!' => 'Musíte vybrat soubor, který nahrajete jako svého avatara!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Soubor, který jste nahráli, není platný obrázek! (Povoleny jsou pouze *.gif, *.jpg, *.jpeg a *.png!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Automaticky nastavit datum splatnosti, když je úkol přesunut z konkrétního sloupce',
+    'No other projects found.' => 'Nebyly nalezeny žádné další projekty.',
+    'Tasks copied successfully.' => 'Úkoly úspěšně zkopírovány.',
+    'Unable to copy tasks.' => 'Nelze kopírovat úkoly.',
+    'Theme' => 'Téma',
+    'Theme:' => 'Téma:',
+    'Light theme' => 'Světlé téma',
+    'Dark theme' => 'Tmavé téma',
+    'Automatic theme - Sync with system' => 'Automatické téma - Synchronizace se systémem',
+    'Application managers or more' => 'Správci aplikace a vyšší',
+    'Administrators' => 'Administrátoři',
+    'Visibility:' => 'Viditelnost:',
+    'Standard users' => 'Standardní uživatelé',
+    'Visibility is required' => 'Viditelnost je povinná',
+    'The visibility should be an app role' => 'Viditelnost by měla být rolí aplikace',
+    'Reply' => 'Odpovědět',
+    '%s wrote: ' => '%s napsal:',
+    'Number of visible tasks in this column and swimlane' => 'Počet viditelných úkolů v tomto sloupci a plavecké dráze',
+    'Number of tasks in this swimlane' => 'Počet úkolů v této plavecké dráze',
+    'Unable to find another subtask in progress, you can close this window.' => 'Nelze najít další probíhající dílčí úkol, můžete zavřít toto okno.',
+    'This theme is invalid' => 'Toto téma je neplatné',
+    'This role is invalid' => 'Tato role je neplatná',
+    'This timezone is invalid' => 'Toto časové pásmo je neplatné',
+    'This language is invalid' => 'Tento jazyk je neplatný',
+    'This URL is invalid' => 'Tato URL adresa je neplatná',
+    'Date format invalid' => 'Neplatný formát data',
+    'Time format invalid' => 'Neplatný formát času',
+    'Invalid Mail transport' => 'Neplatný přenos pošty',
+    'Color invalid' => 'Neplatná barva',
+    'This value must be greater or equal to %d' => 'Tato hodnota musí být větší nebo rovna %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Přidat BOM na začátek souboru (vyžadováno pro Microsoft Excel)',
+    'Just add these tag(s)' => 'Stačí přidat tyto štítky',
+    'Remove internal link(s)' => 'Odebrat interní odkaz(y)',
+    'Import tasks from another project' => 'Importovat úkoly z jiného projektu',
+    'Select the project to copy tasks from' => 'Vyberte projekt, ze kterého chcete úkoly kopírovat',
+    'The total maximum allowed attachments size is %sB.' => 'Celková maximální povolená velikost příloh je %sB.',
+    'Add attachments' => 'Přidat přílohy',
+    'Task #%d "%s" is overdue' => 'Úkol #%d "%s" je po termínu',
+    'Enable notifications by default for all new users' => 'Ve výchozím nastavení povolit oznámení pro všechny nové uživatele',
+];
