@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => '.',
     'None' => 'Ingen',
@@ -525,11 +525,11 @@ return array(
     'INR - Indian Rupee' => 'INR - indisk rupee',
     'JPY - Japanese Yen' => 'JPY - japansk yen',
     'NZD - New Zealand Dollar' => 'NZD - new zealandsk dollar',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN – peruviansk sol',
     'RSD - Serbian dinar' => 'RSD - serbisk dinar',
     'CNY - Chinese Yuan' => 'CNY - kinesisk yuan',
     'USD - US Dollar' => 'USD - amerikansk dollar',
-    // 'VES - Venezuelan Bolívar' => '',
+    'VES - Venezuelan Bolívar' => 'VES – venezuelansk bolívar',
     'Destination column' => 'Mål kolonne',
     'Move the task to another column when assigned to a user' => 'Flyt opgave til anden kolonne når den er tildelt bruger',
     'Move the task to another column when assignee is cleared' => 'Flyt opgave til anden kolonne når ansvarlig er ryddet',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Spor ændret for opgave #%d',
     'Assignee changed on task #%d' => 'Tildelte ændret til opgave #%d',
     '%d overdue tasks' => '%d forsinkede opgaver',
-    'Task #%d is overdue' => 'Opgave #%d forsinket',
     'No notification.' => 'Ingen påmindelse.',
     'Mark all as read' => 'Markere alle som læst',
     'Mark as read' => 'Markere som læst',
@@ -1400,8 +1399,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Sorter kolonne efter ansvarlig (Z-A)',
     'Reorder this column by due date (ASC)' => 'Sorter kolonne efter udløbstid (ASC)',
     'Reorder this column by due date (DESC)' => 'Sorter kolonne efter udløbstid (DESC)',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => 'Sortér denne kolonne efter id (stigende)',
+    'Reorder this column by id (DESC)' => 'Sortér denne kolonne efter id (faldende)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s flyttet opgave #%d "%s" til projekt "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Opgave #%d "%s" er flyttet til projekt "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Flyt opgave til anden kolonne når afleveringsdato er mindre end et bestemt antal dage',
@@ -1431,39 +1430,42 @@ return array(
     'You must select a file to upload as your avatar!' => 'Vælg fil som overføres som profil billede!',
     'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Overført fil er ikke et gyldigt billede! (*.gif, *.jpg, *.jpeg eller *.png)',
     'Automatically set the due date when the task is moved away from a specific column' => 'Sæt automatisk afleveringsdato når opgave er flyttet væk fra en bestemt kolonne',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'No other projects found.' => 'Ingen andre projekter fundet.',
+    'Tasks copied successfully.' => 'Opgaver blev kopieret med succes.',
+    'Unable to copy tasks.' => 'Kunne ikke kopiere opgaver.',
+    'Theme' => 'Tema',
+    'Theme:' => 'Tema:',
+    'Light theme' => 'Lyst tema',
+    'Dark theme' => 'Mørkt tema',
+    'Automatic theme - Sync with system' => 'Automatisk tema – synkroniser med systemet',
+    'Application managers or more' => 'Applikationsansvarlige eller højere',
+    'Administrators' => 'Administratorer',
+    'Visibility:' => 'Synlighed:',
+    'Standard users' => 'Standardbrugere',
+    'Visibility is required' => 'Synlighed er påkrævet',
+    'The visibility should be an app role' => 'Synligheden skal være en app-rolle',
+    'Reply' => 'Svar',
+    '%s wrote: ' => '%s skrev: ',
+    'Number of visible tasks in this column and swimlane' => 'Antal synlige opgaver i denne kolonne og bane',
+    'Number of tasks in this swimlane' => 'Antal opgaver i denne bane',
+    'Unable to find another subtask in progress, you can close this window.' => 'Kunne ikke finde en anden underopgave i gang, du kan lukke dette vindue.',
+    'This theme is invalid' => 'Dette tema er ugyldigt',
+    'This role is invalid' => 'Denne rolle er ugyldig',
+    'This timezone is invalid' => 'Denne tidszone er ugyldig',
+    'This language is invalid' => 'Dette sprog er ugyldigt',
+    'This URL is invalid' => 'Denne URL er ugyldig',
+    'Date format invalid' => 'Ugyldigt datoformat',
+    'Time format invalid' => 'Ugyldigt tidsformat',
+    'Invalid Mail transport' => 'Ugyldig mailtransport',
+    'Color invalid' => 'Ugyldig farve',
+    'This value must be greater or equal to %d' => 'Værdien skal være større end eller lig med %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Tilføj en BOM i begyndelsen af filen (krævet af Microsoft Excel)',
+    'Just add these tag(s)' => 'Tilføj blot disse mærker',
+    'Remove internal link(s)' => 'Fjern interne links',
+    'Import tasks from another project' => 'Importer opgaver fra et andet projekt',
+    'Select the project to copy tasks from' => 'Vælg projektet, du vil kopiere opgaver fra',
+    'The total maximum allowed attachments size is %sB.' => 'Den samlede maksimalt tilladte størrelse for vedhæftede filer er %sB.',
+    'Add attachments' => 'Tilføj vedhæftede filer',
+    'Task #%d "%s" is overdue' => 'Opgave #%d "%s" er forfalden',
+    'Enable notifications by default for all new users' => 'Aktiver påmindelser som standard for alle nye brugere',
+];
