@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => '.',
     'None' => 'Keines',
@@ -526,10 +526,10 @@ return array(
     'JPY - Japanese Yen' => 'JPY - Japanische Yen',
     'NZD - New Zealand Dollar' => 'NZD - Neuseeland-Dollar',
     'PEN - Peruvian Sol' => 'PEN - Peruanischer Sol',
-    'RSD - Serbian dinar' => 'RSD - Serbische Dinar',
-    'CNY - Chinese Yuan' => 'CNY - Chinesische Renminbi',
-    'USD - US Dollar' => 'USD - US-Dollar',
-    'VES - Venezuelan Bolívar' => 'VES - Venezolanische Bolívar',
+    'RSD - Serbian dinar' => 'RSD – Serbischer Dinar',
+    'CNY - Chinese Yuan' => 'CNY - Chinesischer Yuan',
+    'USD - US Dollar' => 'USD – US-Dollar',
+    'VES - Venezuelan Bolívar' => 'VES - Venezolanischer Bolívar',
     'Destination column' => 'Zielspalte',
     'Move the task to another column when assigned to a user' => 'Aufgabe in eine andere Spalte verschieben, wenn ein Benutzer zugeordnet wurde.',
     'Move the task to another column when assignee is cleared' => 'Aufgabe in eine andere Spalte verschieben, wenn die Zuordnung gelöscht wurde.',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Neue Swimlane für Aufgabe #%d',
     'Assignee changed on task #%d' => 'Neue Zuordnung für Aufgabe #%d ',
     '%d overdue tasks' => '%d überfällige Aufgaben',
-    'Task #%d is overdue' => 'Aufgabe #%d ist überfällig',
     'No notification.' => 'Keine neuen Benachrichtigungen',
     'Mark all as read' => 'Alles als gelesen markieren',
     'Mark as read' => 'Als gelesen markieren',
@@ -1400,8 +1399,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Spalte nach Zuständigem ordnen (Z-A)',
     'Reorder this column by due date (ASC)' => 'Spalte nach Fälligkeitsdatum ordnen (aufsteigend)',
     'Reorder this column by due date (DESC)' => 'Spalte nach Fälligkeitsdatum ordnen (absteigend)',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => 'Diese Spalte nach ID aufsteigend sortieren',
+    'Reorder this column by id (DESC)' => 'Diese Spalte nach ID absteigend sortieren',
     '%s moved the task #%d "%s" to the project "%s"' => '%s hat die Aufgabe #%d "%s" in das Projekt "%s" verschoben',
     'Task #%d "%s" has been moved to the project "%s"' => 'Aufgabe #%d "%s" wurde in das Projekt "%s" verschoben',
     'Move the task to another column when the due date is less than a certain number of days' => 'Verschieben der Aufgabe in eine andere Spalte, wenn die Fälligkeit kleiner als eine bestimmte Anzahl von Tagen ist',
@@ -1423,47 +1422,50 @@ return array(
     'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Aufgabe einem bestimmten Nutzer zuordnen, wenn die Aufgabe in eine bestimmte Swimlane verschoben wird',
     'Comment' => 'Kommentar',
     'Collapse vertically' => 'Vertikal zuklappen',
-    'Expand vertically' => 'Vertikal aufklappen',
+    'Expand vertically' => 'Vertikal erweitern',
     'MXN - Mexican Peso' => 'MXN - Mexikanischer Peso',
     'Estimated vs actual time per column' => 'Geschätzte vs. tatsächliche Zeit pro Spalte',
     'HUF - Hungarian Forint' => 'HUF - Ungarischer Forint',
     'XBT - Bitcoin' => 'XBT - Bitcoin',
-    'You must select a file to upload as your avatar!' => 'Sie müssen eine Datei auswählen, die als Avatar hochgeladen werden soll!',
-    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Die hochgeladene Datei ist kein gültiges Bild! (Nur *.gif, *.jpg, *.jpeg and *.png sind erlaubt!)',
-    'Automatically set the due date when the task is moved away from a specific column' => 'Automatisches Setzen des Fälligkeitsdatums, wenn die Aufgabe aus einer bestimmten Spalte heraus verschoben wird',
-    'No other projects found.' => 'Keine weiteren Projekte vorhanden.',
-    'Please choose a project you want to copy the tasks from.' => 'Bitte wählen Sie ein Projekt aus, dessen Tickets Sie kopieren möchten.',
-    'Import Tasks' => 'Aufgaben importieren',
-    'Copy' => 'Kopieren',
-    'Tasks copied successfully.' => 'Die Aufgaben wurden erfolgreich kopiert.',
-    'Unable to copy tasks.' => 'Die Aufgaben konnten nicht kopiert werden.',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    'Just add these tag(s)' => 'Schlagwort(e) nur hinzufügen (bereits zugeordnete nicht löschen)',
-    'Remove internal link(s)' => 'Interne Verbindung(en) entfernen',
-);
+    'You must select a file to upload as your avatar!' => 'Sie müssen eine Datei auswählen, um sie als Ihr Avatar hochzuladen!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Die hochgeladene Datei ist kein gültiges Bild! (Nur *.gif, *.jpg, *.jpeg und *.png sind erlaubt!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Fälligkeitsdatum automatisch setzen, wenn die Aufgabe aus einer bestimmten Spalte verschoben wird',
+    'No other projects found.' => 'Keine weiteren Projekte gefunden.',
+    'Tasks copied successfully.' => 'Aufgaben erfolgreich kopiert.',
+    'Unable to copy tasks.' => 'Aufgaben können nicht kopiert werden.',
+    'Theme' => 'Thema',
+    'Theme:' => 'Thema:',
+    'Light theme' => 'Helles Thema',
+    'Dark theme' => 'Dunkles Thema',
+    'Automatic theme - Sync with system' => 'Automatisches Thema - Mit System synchronisieren',
+    'Application managers or more' => 'Anwendungsmanager oder mehr',
+    'Administrators' => 'Administratoren',
+    'Visibility:' => 'Sichtbarkeit:',
+    'Standard users' => 'Standardbenutzer',
+    'Visibility is required' => 'Sichtbarkeit ist erforderlich',
+    'The visibility should be an app role' => 'Die Sichtbarkeit sollte eine App-Rolle sein',
+    'Reply' => 'Antworten',
+    '%s wrote: ' => '%s schrieb: ',
+    'Number of visible tasks in this column and swimlane' => 'Anzahl sichtbarer Aufgaben in dieser Spalte und Swimlane',
+    'Number of tasks in this swimlane' => 'Anzahl der Aufgaben in dieser Swimlane',
+    'Unable to find another subtask in progress, you can close this window.' => 'Es konnte keine weitere Teilaufgabe in Bearbeitung gefunden werden, Sie können dieses Fenster schließen.',
+    'This theme is invalid' => 'Dieses Thema ist ungültig',
+    'This role is invalid' => 'Diese Rolle ist ungültig',
+    'This timezone is invalid' => 'Diese Zeitzone ist ungültig',
+    'This language is invalid' => 'Diese Sprache ist ungültig',
+    'This URL is invalid' => 'Diese URL ist ungültig',
+    'Date format invalid' => 'Ungültiges Datumsformat',
+    'Time format invalid' => 'Ungültiges Zeitformat',
+    'Invalid Mail transport' => 'Ungültiger Mail-Transport',
+    'Color invalid' => 'Ungültige Farbe',
+    'This value must be greater or equal to %d' => 'Dieser Wert muss größer oder gleich %d sein',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Fügen Sie am Anfang der Datei ein BOM hinzu (erforderlich für Microsoft Excel)',
+    'Just add these tag(s)' => 'Nur diese Tags hinzufügen',
+    'Remove internal link(s)' => 'Interne Links entfernen',
+    'Import tasks from another project' => 'Aufgaben aus einem anderen Projekt importieren',
+    'Select the project to copy tasks from' => 'Wählen Sie das Projekt aus, aus dem Sie Aufgaben kopieren möchten',
+    'The total maximum allowed attachments size is %sB.' => 'Die maximal zulässige Gesamtgröße für Anhänge beträgt %sB.',
+    'Add attachments' => 'Anhänge hinzufügen',
+    'Task #%d "%s" is overdue' => 'Aufgabe #%d "%s" ist überfällig',
+    'Enable notifications by default for all new users' => 'Benachrichtigungen standardmäßig für alle neuen Benutzer aktivieren',
+];
