@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => '.',
     'None' => 'Nema',
@@ -525,7 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Indijski rupi',
     'JPY - Japanese Yen' => 'JPY - Japanski yen',
     'NZD - New Zealand Dollar' => 'NZD - Novozelandski dolar',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - Peruanski Sol',
     'RSD - Serbian dinar' => 'RSD - Srpski dinar',
     'CNY - Chinese Yuan' => 'CNY - Kineski jen',
     'USD - US Dollar' => 'USD - Američki dolar',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Staza izmjenjena za zadatak #%d',
     'Assignee changed on task #%d' => 'Izvršitelj je promijenjen na zadatku #%d',
     '%d overdue tasks' => '%d zadataka kasni',
-    'Task #%d is overdue' => 'Zadatak #%d kasni',
     'No notification.' => 'Nema novih obavijesti.',
     'Mark all as read' => 'Označi sve kao pročitano',
     'Mark as read' => 'Označi kao pročitano',
@@ -1400,8 +1399,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Presloži ovaj stupac po izvršitelju (Ž-A)',
     'Reorder this column by due date (ASC)' => 'Presloži ovaj stupac po roku završetka (UZLAZNO)',
     'Reorder this column by due date (DESC)' => 'Presloži ovaj stupac po roku završetka (SILAZNO)',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => 'Poredaj stupac po id-u (ASC)',
+    'Reorder this column by id (DESC)' => 'Poredaj stupac po id-u (DESC)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s je premjestio/la zadatak #%d "%s" u projekt "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Zadatak #%d "%s" je premješten u projekt "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Pomakni zadatak u drugi stupac kada je datum roka završetka kraći od određenog broja dana',
@@ -1428,42 +1427,45 @@ return array(
     'Estimated vs actual time per column' => 'Procijenjeno u odnosu na stvarno vrijeme po stupcu',
     'HUF - Hungarian Forint' => 'HUD - Mađarska forinta',
     'XBT - Bitcoin' => 'XBT - Bitcoin',
-    // 'You must select a file to upload as your avatar!' => '',
-    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'You must select a file to upload as your avatar!' => 'Morate odabrati datoteku za prijenos kao svoj avatar!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Datoteka koju ste prenijeli nije važeća slika! (Dopušteni su samo *.gif, *.jpg, *.jpeg i *.png!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Automatski postavite datum dospijeća kada se zadatak premjesti iz određenog stupca',
+    'No other projects found.' => 'Nema pronađenih drugih projekata.',
+    'Tasks copied successfully.' => 'Zadaci uspješno kopirani.',
+    'Unable to copy tasks.' => 'Nije moguće kopirati zadatke.',
+    'Theme' => 'Tema',
+    'Theme:' => 'Tema:',
+    'Light theme' => 'Svijetla tema',
+    'Dark theme' => 'Tamna tema',
+    'Automatic theme - Sync with system' => 'Automatska tema - Sinkronizacija sa sustavom',
+    'Application managers or more' => 'Voditelji aplikacija ili više',
+    'Administrators' => 'Administratori',
+    'Visibility:' => 'Vidljivost:',
+    'Standard users' => 'Standardni korisnici',
+    'Visibility is required' => 'Vidljivost je obavezna',
+    'The visibility should be an app role' => 'Vidljivost bi trebala biti uloga aplikacije',
+    'Reply' => 'Odgovori',
+    '%s wrote: ' => '%s napisao: ',
+    'Number of visible tasks in this column and swimlane' => 'Broj vidljivih zadataka u ovom stupcu i plivačkoj stazi',
+    'Number of tasks in this swimlane' => 'Broj zadataka u ovoj plivačkoj stazi',
+    'Unable to find another subtask in progress, you can close this window.' => 'Nije moguće pronaći drugi podzadatak u tijeku, možete zatvoriti ovaj prozor.',
+    'This theme is invalid' => 'Ova tema je nevažeća',
+    'This role is invalid' => 'Ova uloga je nevažeća',
+    'This timezone is invalid' => 'Ova vremenska zona je nevažeća',
+    'This language is invalid' => 'Ovaj jezik je nevažeći',
+    'This URL is invalid' => 'Ovaj URL je nevažeći',
+    'Date format invalid' => 'Format datuma nevažeći',
+    'Time format invalid' => 'Format vremena nevažeći',
+    'Invalid Mail transport' => 'Nevažeći transport pošte',
+    'Color invalid' => 'Boja nevažeća',
+    'This value must be greater or equal to %d' => 'Ova vrijednost mora biti veća ili jednaka %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Dodajte BOM na početak datoteke (obavezno za Microsoft Excel)',
+    'Just add these tag(s)' => 'Samo dodajte ove oznake',
+    'Remove internal link(s)' => 'Uklonite unutarnje poveznice',
+    'Import tasks from another project' => 'Uvezite zadatke iz drugog projekta',
+    'Select the project to copy tasks from' => 'Odaberite projekt iz kojeg želite kopirati zadatke',
+    'The total maximum allowed attachments size is %sB.' => 'Ukupna maksimalna dopuštena veličina privitaka je %sB.',
+    'Add attachments' => 'Dodaj privitke',
+    'Task #%d "%s" is overdue' => 'Zadatak #%d "%s" je istekao',
+    'Enable notifications by default for all new users' => 'Omogući obavijesti prema zadanim postavkama za sve nove korisnike',
+];
