@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => ' ',
     'None' => 'Tidak satupun',
@@ -316,8 +316,8 @@ return array(
     'Remote' => 'Jarak Jauh',
     'Enabled' => 'Aktif',
     'Disabled' => 'Nonaktif',
-    // 'Login:' => '',
-    // 'Full Name:' => '',
+    'Login:' => 'Masuk:',
+    'Full Name:' => 'Nama Lengkap:',
     'Email:' => 'Email:',
     'Notifications:' => 'Pemberitahuan:',
     'Notifications' => 'Pemberitahuan',
@@ -525,11 +525,11 @@ return array(
     'INR - Indian Rupee' => 'INR - Rupe India',
     'JPY - Japanese Yen' => 'JPY - Yen Jepang',
     'NZD - New Zealand Dollar' => 'NZD - Dolar Selandia baru',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - Sol Peru',
     'RSD - Serbian dinar' => 'RSD - Dinar Serbia',
-    // 'CNY - Chinese Yuan' => '',
+    'CNY - Chinese Yuan' => 'CNY - Yuan Tiongkok',
     'USD - US Dollar' => 'USD - Dolar Amerika',
-    // 'VES - Venezuelan Bolívar' => '',
+    'VES - Venezuelan Bolívar' => 'VES - Bolivar Venezuela',
     'Destination column' => 'Kolom tujuan',
     'Move the task to another column when assigned to a user' => 'Pindahkan tugas ke kolom lain saat ditugaskan ke pengguna',
     'Move the task to another column when assignee is cleared' => 'Pindahkan tugas ke kolom lain saat orang yang ditugaskan kosong',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Swimlane diganti untuk tugas #%d',
     'Assignee changed on task #%d' => 'Orang yang ditugaskan diganti pada tugas #%d',
     '%d overdue tasks' => '%d tugas kadaluarsa',
-    'Task #%d is overdue' => 'Tugas #%d sudah kadaluarsa',
     'No notification.' => 'Tidak ada notifikasi baru',
     'Mark all as read' => 'Tandai semua sebagai sudah dibaca',
     'Mark as read' => 'Tandai sebagai sudah dibaca',
@@ -1400,8 +1399,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Susun ulang kolom ini oleh penerima tugas (Z-A)',
     'Reorder this column by due date (ASC)' => 'Susun ulang kolom ini sebelum tanggal jatuh tempo (ASC)',
     'Reorder this column by due date (DESC)' => 'Susun ulang kolom ini berdasarkan tanggal jatuh tempo (DESC)',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => 'Susun ulang kolom ini berdasarkan id (ASC)',
+    'Reorder this column by id (DESC)' => 'Susun ulang kolom ini berdasarkan id (DESC)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s memindahkan tugas #%d "%s" ke proyek "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Task #%d "%s" telah dipindahkan ke proyek "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Pindahkan tugas ke kolom lain ketika batas waktu kurang dari jumlah hari tertentu',
@@ -1424,46 +1423,49 @@ return array(
     'Comment' => 'Komentar',
     'Collapse vertically' => 'Ciutkan secara vertikal',
     'Expand vertically' => 'Bentangkan secara vertikal',
-    // 'MXN - Mexican Peso' => '',
-    // 'Estimated vs actual time per column' => '',
-    // 'HUF - Hungarian Forint' => '',
+    'MXN - Mexican Peso' => 'MXN - Peso Meksiko',
+    'Estimated vs actual time per column' => 'Estimasi vs waktu aktual per kolom',
+    'HUF - Hungarian Forint' => 'HUF - Forint Hongaria',
     'XBT - Bitcoin' => 'XBT - Bitcoin',
-    // 'You must select a file to upload as your avatar!' => '',
-    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'You must select a file to upload as your avatar!' => 'Anda harus memilih berkas untuk diunggah sebagai avatar Anda!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Berkas yang Anda unggah bukan gambar yang valid! (Hanya berkas *.gif, *.jpg, *.jpeg, dan *.png yang diizinkan!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Atur tenggat waktu secara otomatis ketika tugas dipindahkan dari kolom tertentu',
+    'No other projects found.' => 'Tidak ada proyek lain yang ditemukan.',
+    'Tasks copied successfully.' => 'Tugas berhasil disalin.',
+    'Unable to copy tasks.' => 'Tidak dapat menyalin tugas.',
+    'Theme' => 'Tema',
+    'Theme:' => 'Tema:',
+    'Light theme' => 'Tema terang',
+    'Dark theme' => 'Tema gelap',
+    'Automatic theme - Sync with system' => 'Tema otomatis - Sinkronkan dengan sistem',
+    'Application managers or more' => 'Pengelola aplikasi atau lebih',
+    'Administrators' => 'Administrator',
+    'Visibility:' => 'Visibilitas:',
+    'Standard users' => 'Pengguna standar',
+    'Visibility is required' => 'Visibilitas diperlukan',
+    'The visibility should be an app role' => 'Visibilitas harus berupa peran aplikasi',
+    'Reply' => 'Balas',
+    '%s wrote: ' => '%s menulis: ',
+    'Number of visible tasks in this column and swimlane' => 'Jumlah tugas yang terlihat di kolom dan lajur ini',
+    'Number of tasks in this swimlane' => 'Jumlah tugas di lajur ini',
+    'Unable to find another subtask in progress, you can close this window.' => 'Tidak dapat menemukan subtugas lain dalam proses, Anda dapat menutup jendela ini.',
+    'This theme is invalid' => 'Tema ini tidak valid',
+    'This role is invalid' => 'Peran ini tidak valid',
+    'This timezone is invalid' => 'Zona waktu ini tidak valid',
+    'This language is invalid' => 'Bahasa ini tidak valid',
+    'This URL is invalid' => 'URL ini tidak valid',
+    'Date format invalid' => 'Format tanggal tidak valid',
+    'Time format invalid' => 'Format waktu tidak valid',
+    'Invalid Mail transport' => 'Transportasi surel tidak valid',
+    'Color invalid' => 'Warna tidak valid',
+    'This value must be greater or equal to %d' => 'Nilai ini harus lebih besar dari atau sama dengan %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Tambahkan BOM di awal berkas (diperlukan untuk Microsoft Excel)',
+    'Just add these tag(s)' => 'Cukup tambahkan tag ini',
+    'Remove internal link(s)' => 'Hapus tautan internal',
+    'Import tasks from another project' => 'Impor tugas dari proyek lain',
+    'Select the project to copy tasks from' => 'Pilih proyek untuk menyalin tugas darinya',
+    'The total maximum allowed attachments size is %sB.' => 'Ukuran total maksimum lampiran yang diizinkan adalah %sB.',
+    'Add attachments' => 'Tambahkan lampiran',
+    'Task #%d "%s" is overdue' => 'Tugas #%d "%s" sudah kadaluarsa',
+    'Enable notifications by default for all new users' => 'Aktifkan notifikasi secara default untuk semua pengguna baru',
+];
