@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => '.',
     'None' => 'Nessuno',
@@ -525,11 +525,11 @@ return array(
     'INR - Indian Rupee' => 'INR - Rupie Indiani',
     'JPY - Japanese Yen' => 'JPY - Yen Giapponesi',
     'NZD - New Zealand Dollar' => 'NZD - Dollari della Nuova Zelanda',
-    'PEN - Peruvian Sol' => 'PEN - Sol Peruviano',
-    'RSD - Serbian dinar' => 'RSD - Dinar Serbi',
-    'CNY - Chinese Yuan' => 'CNY - Yuan Cinese',
+    'PEN - Peruvian Sol' => 'PEN - Sol peruviano',
+    'RSD - Serbian dinar' => 'RSD - Dinar serbo',
+    'CNY - Chinese Yuan' => 'CNY - Yuan cinese',
     'USD - US Dollar' => 'USD - Dollari Americani',
-    'VES - Venezuelan Bolívar' => 'Bolívar venezuelano',
+    'VES - Venezuelan Bolívar' => 'VES - Bolívar venezuelano',
     'Destination column' => 'Colonna destinazione',
     'Move the task to another column when assigned to a user' => 'Sposta il compito in un\'altra colonna quando viene assegnato ad un utente',
     'Move the task to another column when assignee is cleared' => 'Sposta il compito in un\'altra colonna quando l\'assegnatario viene cancellato',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Corsia modificata per il compito #%d',
     'Assignee changed on task #%d' => 'Assegnatario modificato per il compito #%d',
     '%d overdue tasks' => '%d compiti scaduti',
-    'Task #%d is overdue' => 'Il compito #%d è scaduto',
     'No notification.' => 'Nessuna nuova notifica.',
     'Mark all as read' => 'Segna tutti come letti',
     'Mark as read' => 'Segna come letto',
@@ -1425,16 +1424,13 @@ return array(
     'Collapse vertically' => 'Riduci verticalmente',
     'Expand vertically' => 'Espandi verticalmente',
     'MXN - Mexican Peso' => 'MXN - Peso messicano',
-    'Estimated vs actual time per column' => 'Tempo per colonna stimato contro effettivo',
+    'Estimated vs actual time per column' => 'Tempo stimato vs reale per colonna',
     'HUF - Hungarian Forint' => 'HUF - Fiorino ungherese',
     'XBT - Bitcoin' => 'XBT - Bitcoin',
-    'You must select a file to upload as your avatar!' => 'Devi selezionare un file da caricare come avatar',
-    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Il documento che hai caricato non è un\'immagine valida! (Sono permesse solo *.gif, *.jpg, *.jpeg and *.png)',
-    'Automatically set the due date when the task is moved away from a specific column' => 'Imposta automaticamente la data di scadenza quando il compito viene spostato ad una colonna specifica',
+    'You must select a file to upload as your avatar!' => 'Devi selezionare un file da caricare come avatar!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Il file caricato non è un\'immagine valida! (Sono consentiti solo *.gif, *.jpg, *.jpeg e *.png!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Imposta automaticamente la data di scadenza quando il task viene spostato da una colonna specifica',
     'No other projects found.' => 'Nessun altro progetto trovato.',
-    'Please choose a project you want to copy the tasks from.' => 'Per favore, scegli un progetto da cui copiare le attività.',
-    'Import Tasks' => 'Importa attività',
-    'Copy' => 'Copia',
     'Tasks copied successfully.' => 'Attività copiate con successo.',
     'Unable to copy tasks.' => 'Impossibile copiare le attività.',
     'Theme' => 'Tema',
@@ -1442,28 +1438,34 @@ return array(
     'Light theme' => 'Tema chiaro',
     'Dark theme' => 'Tema scuro',
     'Automatic theme - Sync with system' => 'Tema automatico - Sincronizza con il sistema',
-    'Application managers or more' => 'Manager o altro',
+    'Application managers or more' => 'Gestori dell\'applicazione o più',
     'Administrators' => 'Amministratori',
     'Visibility:' => 'Visibilità:',
     'Standard users' => 'Utenti standard',
-    'Visibility is required' => 'La visibilità è richiesta',
-    'The visibility should be an app role' => 'La visibilità dovrebbe essere un ruolo dell\'app',
+    'Visibility is required' => 'La visibilità è obbligatoria',
+    'The visibility should be an app role' => 'La visibilità deve essere un ruolo dell\'applicazione',
     'Reply' => 'Rispondi',
-    '%s wrote: ' => '%s ha scritto',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    '%s wrote: ' => '%s ha scritto: ',
+    'Number of visible tasks in this column and swimlane' => 'Numero di attività visibili in questa colonna e swimlane',
+    'Number of tasks in this swimlane' => 'Numero di attività in questa swimlane',
+    'Unable to find another subtask in progress, you can close this window.' => 'Impossibile trovare un\'altra sotto-attività in corso, puoi chiudere questa finestra.',
+    'This theme is invalid' => 'Questo tema non è valido',
+    'This role is invalid' => 'Questo ruolo non è valido',
+    'This timezone is invalid' => 'Questo fuso orario non è valido',
+    'This language is invalid' => 'Questa lingua non è valida',
+    'This URL is invalid' => 'Questo URL non è valido',
+    'Date format invalid' => 'Formato data non valido',
+    'Time format invalid' => 'Formato ora non valido',
+    'Invalid Mail transport' => 'Trasporto email non valido',
+    'Color invalid' => 'Colore non valido',
+    'This value must be greater or equal to %d' => 'Questo valore deve essere maggiore o uguale a %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Aggiungi un BOM all\'inizio del file (richiesto per Microsoft Excel)',
+    'Just add these tag(s)' => 'Aggiungi solo queste etichette',
+    'Remove internal link(s)' => 'Rimuovi i collegamenti interni',
+    'Import tasks from another project' => 'Importa attività da un altro progetto',
+    'Select the project to copy tasks from' => 'Seleziona il progetto da cui copiare le attività',
+    'The total maximum allowed attachments size is %sB.' => 'La dimensione massima totale consentita per gli allegati è %sB.',
+    'Add attachments' => 'Aggiungi allegati',
+    'Task #%d "%s" is overdue' => 'Il compito #%d "%s" è scaduto',
+    'Enable notifications by default for all new users' => 'Abilita le notifiche per impostazione predefinita per tutti i nuovi utenti',
+];
