@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => '.',
     'None' => 'Ingen',
@@ -525,11 +525,11 @@ return array(
     'INR - Indian Rupee' => 'INR - Indiske rupi',
     'JPY - Japanese Yen' => 'JPY - Japanske yen',
     'NZD - New Zealand Dollar' => 'NZD - New Zealand Dollar',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - Peruansk sol',
     'RSD - Serbian dinar' => 'RSD - Serbiske dinarer',
     'CNY - Chinese Yuan' => 'CNY - Kinesiske yuan',
     'USD - US Dollar' => 'USD - Amerikanske dollar',
-    // 'VES - Venezuelan Bolívar' => '',
+    'VES - Venezuelan Bolívar' => 'VES - Venezuelansk bolívar',
     'Destination column' => 'Ny kolonne',
     'Move the task to another column when assigned to a user' => 'Flytt oppgaven til en annen kolonne når den er tildelt en bruker',
     'Move the task to another column when assignee is cleared' => 'Flytt oppgaven til en annen kolonne når ppgavetildeling fjernes ',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Svømmebane er endret for oppgaven #%d',
     'Assignee changed on task #%d' => 'Ansvarlig er endret for oppgaven #%d',
     '%d overdue tasks' => '%d forfalte oppgaver',
-    'Task #%d is overdue' => 'Oppgave #%d er forfalt',
     'No notification.' => 'Ingen varslinger',
     'Mark all as read' => 'Merk alle som lest',
     'Mark as read' => 'Merk som lest',
@@ -1383,87 +1382,90 @@ return array(
     'Choose the properties that you would like to change for the selected tasks.' => 'Velg egenskapene du vil endre for valgte oppgaver.',
     'Configure this project' => 'Prosjekt',
     'Start now' => 'Start nå',
-    // '%s removed a file from the task #%d' => '',
-    // 'Attachment removed from task #%d: %s' => '',
-    // 'No color' => '',
-    // 'Attachment removed "%s"' => '',
-    // '%s removed a file from the task %s' => '',
-    // 'Move the task to another swimlane when assigned to a user' => '',
-    // 'Destination swimlane' => '',
-    // 'Assign a category when the task is moved to a specific swimlane' => '',
-    // 'Move the task to another swimlane when the category is changed' => '',
-    // 'Reorder this column by priority (ASC)' => '',
-    // 'Reorder this column by priority (DESC)' => '',
-    // 'Reorder this column by assignee and priority (ASC)' => '',
-    // 'Reorder this column by assignee and priority (DESC)' => '',
-    // 'Reorder this column by assignee (A-Z)' => '',
-    // 'Reorder this column by assignee (Z-A)' => '',
-    // 'Reorder this column by due date (ASC)' => '',
-    // 'Reorder this column by due date (DESC)' => '',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
-    // '%s moved the task #%d "%s" to the project "%s"' => '',
-    // 'Task #%d "%s" has been moved to the project "%s"' => '',
-    // 'Move the task to another column when the due date is less than a certain number of days' => '',
-    // 'Automatically update the start date when the task is moved away from a specific column' => '',
-    // 'HTTP Client:' => '',
-    // 'Assigned' => '',
-    // 'Task limits apply to each swimlane individually' => '',
-    // 'Column task limits apply to each swimlane individually' => '',
-    // 'Column task limits are applied to each swimlane individually' => '',
-    // 'Column task limits are applied across swimlanes' => '',
-    // 'Task limit: ' => '',
-    // 'Change to global tag' => '',
-    // 'Do you really want to make the tag "%s" global?' => '',
-    // 'Enable global tags for this project' => '',
-    // 'Group membership(s):' => '',
-    // '%s is a member of the following group(s): %s' => '',
-    // '%d/%d group(s) shown' => '',
-    // 'Subtask creation or modification' => '',
-    // 'Assign the task to a specific user when the task is moved to a specific swimlane' => '',
-    // 'Comment' => '',
-    // 'Collapse vertically' => '',
-    // 'Expand vertically' => '',
-    // 'MXN - Mexican Peso' => '',
-    // 'Estimated vs actual time per column' => '',
-    // 'HUF - Hungarian Forint' => '',
-    // 'XBT - Bitcoin' => '',
-    // 'You must select a file to upload as your avatar!' => '',
-    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    '%s removed a file from the task #%d' => '%s fjernet en fil fra oppgaven #%d',
+    'Attachment removed from task #%d: %s' => 'Vedlegg fjernet fra oppgave #%d: %s',
+    'No color' => 'Ingen farge',
+    'Attachment removed "%s"' => 'Vedlegg fjernet "%s"',
+    '%s removed a file from the task %s' => '%s fjernet en fil fra oppgaven %s',
+    'Move the task to another swimlane when assigned to a user' => 'Flytt oppgaven til en annen svømmebane når den tildeles en bruker',
+    'Destination swimlane' => 'Mål-svømmebane',
+    'Assign a category when the task is moved to a specific swimlane' => 'Tildel en kategori når oppgaven flyttes til en bestemt svømmebane',
+    'Move the task to another swimlane when the category is changed' => 'Flytt oppgaven til en annen svømmebane når kategorien endres',
+    'Reorder this column by priority (ASC)' => 'Sorter denne kolonnen etter prioritet (stigende)',
+    'Reorder this column by priority (DESC)' => 'Sorter denne kolonnen etter prioritet (synkende)',
+    'Reorder this column by assignee and priority (ASC)' => 'Sorter denne kolonnen etter ansvarlig og prioritet (stigende)',
+    'Reorder this column by assignee and priority (DESC)' => 'Sorter denne kolonnen etter ansvarlig og prioritet (synkende)',
+    'Reorder this column by assignee (A-Z)' => 'Sorter denne kolonnen etter ansvarlig (A–Å)',
+    'Reorder this column by assignee (Z-A)' => 'Sorter denne kolonnen etter ansvarlig (Å–A)',
+    'Reorder this column by due date (ASC)' => 'Sorter denne kolonnen etter forfallsdato (stigende)',
+    'Reorder this column by due date (DESC)' => 'Sorter denne kolonnen etter forfallsdato (synkende)',
+    'Reorder this column by id (ASC)' => 'Sorter denne kolonnen etter ID (stigende)',
+    'Reorder this column by id (DESC)' => 'Sorter denne kolonnen etter ID (synkende)',
+    '%s moved the task #%d "%s" to the project "%s"' => '%s flyttet oppgaven #%d "%s" til prosjektet "%s"',
+    'Task #%d "%s" has been moved to the project "%s"' => 'Oppgave #%d "%s" har blitt flyttet til prosjektet "%s"',
+    'Move the task to another column when the due date is less than a certain number of days' => 'Flytt oppgaven til en annen kolonne når forfallsdatoen er mindre enn et bestemt antall dager',
+    'Automatically update the start date when the task is moved away from a specific column' => 'Oppdater startdatoen automatisk når oppgaven flyttes fra en bestemt kolonne',
+    'HTTP Client:' => 'HTTP-klient:',
+    'Assigned' => 'Tildelt',
+    'Task limits apply to each swimlane individually' => 'Oppgavegrenser gjelder for hver svømmebane individuelt',
+    'Column task limits apply to each swimlane individually' => 'Kolonneoppgavegrenser gjelder for hver svømmebane individuelt',
+    'Column task limits are applied to each swimlane individually' => 'Kolonneoppgavegrenser brukes på hver svømmebane individuelt',
+    'Column task limits are applied across swimlanes' => 'Kolonneoppgavegrenser brukes på tvers av svømmebaner',
+    'Task limit: ' => 'Oppgavegrense: ',
+    'Change to global tag' => 'Endre til global tag',
+    'Do you really want to make the tag "%s" global?' => 'Vil du virkelig gjøre taggen "%s" global?',
+    'Enable global tags for this project' => 'Aktiver globale tagger for dette prosjektet',
+    'Group membership(s):' => 'Gruppemedlemskap:',
+    '%s is a member of the following group(s): %s' => '%s er medlem av følgende gruppe(r): %s',
+    '%d/%d group(s) shown' => '%d/%d gruppe(r) vist',
+    'Subtask creation or modification' => 'Opprettelse eller endring av deloppgave',
+    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Tildel oppgaven til en bestemt bruker når den flyttes til en bestemt svømmebane',
+    'Comment' => 'Kommentar',
+    'Collapse vertically' => 'Skjul vertikalt',
+    'Expand vertically' => 'Utvid vertikalt',
+    'MXN - Mexican Peso' => 'MXN - Meksikansk peso',
+    'Estimated vs actual time per column' => 'Estimert vs faktisk tid per kolonne',
+    'HUF - Hungarian Forint' => 'HUF - Ungarsk forint',
+    'XBT - Bitcoin' => 'XBT - Bitcoin',
+    'You must select a file to upload as your avatar!' => 'Du må velge en fil for å laste opp som din avatar!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Filen du lastet opp er ikke et gyldig bilde! (Kun *.gif, *.jpg, *.jpeg og *.png er tillatt!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Angi forfallsdato automatisk når oppgaven flyttes fra en bestemt kolonne',
+    'No other projects found.' => 'Ingen andre prosjekter funnet.',
+    'Tasks copied successfully.' => 'Oppgaver kopiert vellykket.',
+    'Unable to copy tasks.' => 'Kan ikke kopiere oppgaver.',
+    'Theme' => 'Tema',
+    'Theme:' => 'Tema:',
+    'Light theme' => 'Lyst tema',
+    'Dark theme' => 'Mørkt tema',
+    'Automatic theme - Sync with system' => 'Automatisk tema - Synkroniser med systemet',
+    'Application managers or more' => 'Applikasjonsadministratorer eller høyere',
+    'Administrators' => 'Administratorer',
+    'Visibility:' => 'Synlighet:',
+    'Standard users' => 'Standardbrukere',
+    'Visibility is required' => 'Synlighet er påkrevd',
+    'The visibility should be an app role' => 'Synligheten bør være en applikasjonsrolle',
+    'Reply' => 'Svar',
+    '%s wrote: ' => '%s skrev: ',
+    'Number of visible tasks in this column and swimlane' => 'Antall synlige oppgaver i denne kolonnen og svømmebanen',
+    'Number of tasks in this swimlane' => 'Antall oppgaver i denne svømmebanen',
+    'Unable to find another subtask in progress, you can close this window.' => 'Kan ikke finne en annen deloppgave i arbeid, du kan lukke dette vinduet.',
+    'This theme is invalid' => 'Dette temaet er ugyldig',
+    'This role is invalid' => 'Denne rollen er ugyldig',
+    'This timezone is invalid' => 'Denne tidssonen er ugyldig',
+    'This language is invalid' => 'Dette språket er ugyldig',
+    'This URL is invalid' => 'Denne URL-en er ugyldig',
+    'Date format invalid' => 'Ugyldig datoformat',
+    'Time format invalid' => 'Ugyldig tidsformat',
+    'Invalid Mail transport' => 'Ugyldig e-posttransport',
+    'Color invalid' => 'Ugyldig farge',
+    'This value must be greater or equal to %d' => 'Denne verdien må være større enn eller lik %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Legg til en BOM i begynnelsen av filen (påkrevd for Microsoft Excel)',
+    'Just add these tag(s)' => 'Bare legg til disse taggene',
+    'Remove internal link(s)' => 'Fjern interne lenker',
+    'Import tasks from another project' => 'Importer oppgaver fra et annet prosjekt',
+    'Select the project to copy tasks from' => 'Velg prosjektet du vil kopiere oppgaver fra',
+    'The total maximum allowed attachments size is %sB.' => 'Den totale maksimalt tillatte vedleggsstørrelsen er %sB.',
+    'Add attachments' => 'Legg til vedlegg',
+    'Task #%d "%s" is overdue' => 'Oppgaven #%d "%s" er forsinket',
+    'Enable notifications by default for all new users' => 'Aktiver varslinger som standard for alle nye brukere',
+];
