@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => '.',
     'None' => 'Geen',
@@ -525,11 +525,11 @@ return array(
     'INR - Indian Rupee' => 'INR - Indiaase rupee',
     'JPY - Japanese Yen' => 'JPY - Japanse yen',
     'NZD - New Zealand Dollar' => 'NZD - Nieuw-Zeelandse dollar',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - Peruaanse sol',
     'RSD - Serbian dinar' => 'RSD - Servische dinar',
     'CNY - Chinese Yuan' => 'CNY - Chinese yuan',
     'USD - US Dollar' => 'USD - Amerikaanse dollar',
-    'VES - Venezuelan Bolívar' => 'VES - Venezolaanse bolívar',
+    'VES - Venezuelan Bolívar' => 'VES - Venezolaanse bolivar',
     'Destination column' => 'Doelkolom',
     'Move the task to another column when assigned to a user' => 'Verplaats de taak naar een andere kolom wanneer deze is toegewezen aan een gebruiker',
     'Move the task to another column when assignee is cleared' => 'Verplaats de taak naar een andere kolom wanneer de toewijzing is verwijderd',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Swimlane gewijzigd voor taak #%d',
     'Assignee changed on task #%d' => 'Toegewezene gewijzigd voor taak #%d',
     '%d overdue tasks' => '%d achterstallige taken',
-    'Task #%d is overdue' => 'Taak #%d is te laat',
     'No notification.' => 'Geen melding.',
     'Mark all as read' => 'Markeer alles als gelezen',
     'Mark as read' => 'Markeer als gelezen',
@@ -1425,45 +1424,48 @@ return array(
     'Collapse vertically' => 'Verticaal samenvouwen',
     'Expand vertically' => 'Verticaal uitvouwen',
     'MXN - Mexican Peso' => 'MXN - Mexicaanse peso',
-    'Estimated vs actual time per column' => 'Geschatte vs. werkelijke tijd per kolom',
+    'Estimated vs actual time per column' => 'Geschatte vs werkelijke tijd per kolom',
     'HUF - Hungarian Forint' => 'HUF - Hongaarse forint',
     'XBT - Bitcoin' => 'XBT - Bitcoin',
-    'You must select a file to upload as your avatar!' => 'Je moet een bestand selecteren om te uploaden als je avatar!',
-    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Het bestand dat je hebt geüpload is geen geldige afbeelding! (Alleen *.gif, *.jpg, *.jpeg en *.png zijn toegestaan!)',
-    'Automatically set the due date when the task is moved away from a specific column' => 'Stel automatisch de vervaldatum in wanneer de taak wordt verplaatst van een specifieke kolom',
+    'You must select a file to upload as your avatar!' => 'U moet een bestand selecteren om als uw avatar te uploaden!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Het bestand dat u heeft geüpload is geen geldige afbeelding! (Alleen *.gif, *.jpg, *.jpeg en *.png zijn toegestaan!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Stel automatisch de vervaldatum in wanneer de taak uit een specifieke kolom wordt verplaatst',
     'No other projects found.' => 'Geen andere projecten gevonden.',
-    'Please choose a project you want to copy the tasks from.' => 'Kies een project waarvan je de taken wilt kopiëren.',
-    'Import Tasks' => 'Taken importeren',
-    'Copy' => 'Kopiëren',
-    'Tasks copied successfully.' => 'De taken zijn succesvol gekopieerd.',
+    'Tasks copied successfully.' => 'Taken succesvol gekopieerd.',
     'Unable to copy tasks.' => 'Kan taken niet kopiëren.',
     'Theme' => 'Thema',
     'Theme:' => 'Thema:',
     'Light theme' => 'Licht thema',
     'Dark theme' => 'Donker thema',
     'Automatic theme - Sync with system' => 'Automatisch thema - Synchroniseren met systeem',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'Application managers or more' => 'Applicatiebeheerders of meer',
+    'Administrators' => 'Beheerders',
+    'Visibility:' => 'Zichtbaarheid:',
+    'Standard users' => 'Standaardgebruikers',
+    'Visibility is required' => 'Zichtbaarheid is vereist',
+    'The visibility should be an app role' => 'De zichtbaarheid moet een app-rol zijn',
+    'Reply' => 'Beantwoorden',
+    '%s wrote: ' => '%s schreef: ',
+    'Number of visible tasks in this column and swimlane' => 'Aantal zichtbare taken in deze kolom en swimlane',
+    'Number of tasks in this swimlane' => 'Aantal taken in deze swimlane',
+    'Unable to find another subtask in progress, you can close this window.' => 'Kan geen andere subtaak in uitvoering vinden, u kunt dit venster sluiten.',
+    'This theme is invalid' => 'Dit thema is ongeldig',
+    'This role is invalid' => 'Deze rol is ongeldig',
+    'This timezone is invalid' => 'Deze tijdzone is ongeldig',
+    'This language is invalid' => 'Deze taal is ongeldig',
+    'This URL is invalid' => 'Deze URL is ongeldig',
+    'Date format invalid' => 'Ongeldig datumnotatie',
+    'Time format invalid' => 'Ongeldige tijdnotatie',
+    'Invalid Mail transport' => 'Ongeldige mailtransport',
+    'Color invalid' => 'Ongeldige kleur',
+    'This value must be greater or equal to %d' => 'Deze waarde moet groter of gelijk zijn aan %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Voeg een BOM toe aan het begin van het bestand (vereist voor Microsoft Excel)',
+    'Just add these tag(s)' => 'Voeg alleen deze tags toe',
+    'Remove internal link(s)' => 'Verwijder interne links',
+    'Import tasks from another project' => 'Importeer taken uit een ander project',
+    'Select the project to copy tasks from' => 'Selecteer het project waarvan u taken wilt kopiëren',
+    'The total maximum allowed attachments size is %sB.' => 'De maximaal toegestane totale grootte voor bijlagen is %sB.',
+    'Add attachments' => 'Bijlagen toevoegen',
+    'Task #%d "%s" is overdue' => 'Taak #%d "%s" is te laat',
+    'Enable notifications by default for all new users' => 'Standaard meldingen inschakelen voor alle nieuwe gebruikers',
+];
