@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => ' ',
     'None' => 'Brak',
@@ -291,7 +291,7 @@ return array(
     'The task #%d has been closed.' => 'Zadania #%d zostały zamknięte.',
     'Sub-task updated' => 'Pod-zadanie zaktualizowane',
     'Title:' => 'Nazwa:',
-    // 'Status:' => '',
+    'Status:' => 'Status:',
     'Assignee:' => 'Przypisano do:',
     'Time tracking:' => 'Śledzenie czasu: ',
     'New sub-task' => 'Nowe Pod-zadanie',
@@ -525,11 +525,11 @@ return array(
     'INR - Indian Rupee' => 'INR - Rupia indyjska',
     'JPY - Japanese Yen' => 'JPY - Jen japoński',
     'NZD - New Zealand Dollar' => 'NZD - Dolar nowozelandzki',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - Sol peruwiański',
     'RSD - Serbian dinar' => 'RSD - Dinar serbski',
     'CNY - Chinese Yuan' => 'CNY - Juan chiński',
     'USD - US Dollar' => 'USD - Dolar amerykański',
-    // 'VES - Venezuelan Bolívar' => '',
+    'VES - Venezuelan Bolívar' => 'VES - Boliwar wenezuelski',
     'Destination column' => 'Kolumna docelowa',
     'Move the task to another column when assigned to a user' => 'Przenieś zadanie do innej kolumny gdy zostanie przypisane do osoby',
     'Move the task to another column when assignee is cleared' => 'Przenieś zadanie do innej kolumny gdy osoba odpowiedzialna zostanie usunięta',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Zmieniono tor dla zadania #%d',
     'Assignee changed on task #%d' => 'Zmieniono osobę odpowiedzialną dla zadania #%d',
     '%d overdue tasks' => '%d zaległych zadań',
-    'Task #%d is overdue' => 'Zadanie #%d jest zaległe',
     'No notification.' => 'Brak nowych powiadomień.',
     'Mark all as read' => 'Oznacz wszystkie jako przeczytane',
     'Mark as read' => 'Oznacz jako przeczytane',
@@ -1400,8 +1399,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Sortuj kolumnę po osobie przydzielonej do zadania (malejąco)',
     'Reorder this column by due date (ASC)' => 'Sortuj kolumnę po dacie zakończenia (rosnąco)',
     'Reorder this column by due date (DESC)' => 'Sortuj kolumnę po dacie zakończenia (malejąco)',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => 'Sortuj tę kolumnę według ID (rosnąco)',
+    'Reorder this column by id (DESC)' => 'Sortuj tę kolumnę według ID (malejąco)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s przeniósł zadanie nr %d "%s" do projektu "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Zadanie nr %d "%s" zostało przeniesione do projektu "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Przenieś zadanie do innej kolumny, kiedy data zakończenia jest oddalona o określoną liczbę dni od aktualnej daty',
@@ -1430,40 +1429,43 @@ return array(
     'XBT - Bitcoin' => 'XBT - Bitcoin',
     'You must select a file to upload as your avatar!' => 'Musisz wybrać plik, który chcesz przesłać jako swój awatar!',
     'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Przesłany plik nie jest prawidłowym obrazem! (Tylko *.gif, *.jpg, *.jpeg i *.png są dozwolone!)',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'Automatically set the due date when the task is moved away from a specific column' => 'Automatycznie ustaw datę wykonania, gdy zadanie zostanie przeniesione z określonej kolumny',
+    'No other projects found.' => 'Nie znaleziono innych projektów.',
+    'Tasks copied successfully.' => 'Zadania skopiowane pomyślnie.',
+    'Unable to copy tasks.' => 'Nie udało się skopiować zadań.',
+    'Theme' => 'Motyw',
+    'Theme:' => 'Motyw:',
+    'Light theme' => 'Jasny motyw',
+    'Dark theme' => 'Ciemny motyw',
+    'Automatic theme - Sync with system' => 'Motyw automatyczny – synchronizuj z systemem',
+    'Application managers or more' => 'Menedżerowie aplikacji lub wyżej',
+    'Administrators' => 'Administratorzy',
+    'Visibility:' => 'Widoczność:',
+    'Standard users' => 'Użytkownicy standardowi',
+    'Visibility is required' => 'Widoczność jest wymagana',
+    'The visibility should be an app role' => 'Widoczność powinna odpowiadać roli w aplikacji',
+    'Reply' => 'Odpowiedz',
+    '%s wrote: ' => '%s napisał(a): ',
+    'Number of visible tasks in this column and swimlane' => 'Liczba widocznych zadań w tej kolumnie i torze',
+    'Number of tasks in this swimlane' => 'Liczba zadań w tym torze',
+    'Unable to find another subtask in progress, you can close this window.' => 'Nie znaleziono innego podzadania w toku, możesz zamknąć to okno.',
+    'This theme is invalid' => 'Ten motyw jest nieprawidłowy',
+    'This role is invalid' => 'Ta rola jest nieprawidłowa',
+    'This timezone is invalid' => 'Ta strefa czasowa jest nieprawidłowa',
+    'This language is invalid' => 'Ten język jest nieprawidłowy',
+    'This URL is invalid' => 'Ten adres URL jest nieprawidłowy',
+    'Date format invalid' => 'Nieprawidłowy format daty',
+    'Time format invalid' => 'Nieprawidłowy format czasu',
+    'Invalid Mail transport' => 'Nieprawidłowy sposób przesyłania poczty',
+    'Color invalid' => 'Nieprawidłowy kolor',
+    'This value must be greater or equal to %d' => 'Ta wartość musi być większa lub równa %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Dodaj BOM na początku pliku (wymagane dla Microsoft Excel)',
+    'Just add these tag(s)' => 'Po prostu dodaj te tagi',
+    'Remove internal link(s)' => 'Usuń wewnętrzne odnośniki',
+    'Import tasks from another project' => 'Importuj zadania z innego projektu',
+    'Select the project to copy tasks from' => 'Wybierz projekt, z którego chcesz skopiować zadania',
+    'The total maximum allowed attachments size is %sB.' => 'Maksymalny dozwolony rozmiar załączników to %sB.',
+    'Add attachments' => 'Dodaj załączniki',
+    'Task #%d "%s" is overdue' => 'Zadanie nr %d "%s" jest przeterminowane',
+    'Enable notifications by default for all new users' => 'Włącz powiadomienia domyślnie dla wszystkich nowych użytkowników',
+];
