@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => '.',
     'None' => 'Nenhum',
@@ -525,9 +525,9 @@ return array(
     'INR - Indian Rupee' => 'INR - Rúpia indiana',
     'JPY - Japanese Yen' => 'JPY - Iene japonês',
     'NZD - New Zealand Dollar' => 'NZD - Dólar neozelandês',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - Sol peruano',
     'RSD - Serbian dinar' => 'RSD - Dinar sérvio',
-    'CNY - Chinese Yuan' => 'CNY - Yuan Renminbi da China',
+    'CNY - Chinese Yuan' => 'CNY - Yuan chinês',
     'USD - US Dollar' => 'USD - Dólar norte-americano',
     'VES - Venezuelan Bolívar' => 'VES - Bolívar venezuelano',
     'Destination column' => 'Coluna de destino',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Raia alterada para a tarefa #%d',
     'Assignee changed on task #%d' => 'Designação alterada na tarefa #%d',
     '%d overdue tasks' => '%d tarefas atrasadas',
-    'Task #%d is overdue' => 'Tarefa #%d está atrasada',
     'No notification.' => 'Nenhuma notificação nova.',
     'Mark all as read' => 'Marcar todas como lidas',
     'Mark as read' => 'Marcar como lida',
@@ -1400,8 +1399,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Reordenar esta coluna por designado (Z-A)',
     'Reorder this column by due date (ASC)' => 'Reordenar esta coluna por data fim estimada (crescente)',
     'Reorder this column by due date (DESC)' => 'Reordenar esta coluna por data fim estimada (decrescente)',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => 'Reordenar esta coluna por id (ASC)',
+    'Reorder this column by id (DESC)' => 'Reordenar esta coluna por id (DESC)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s moveu a tarefa #%d "%s" para o projeto "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Tarefa #%d "%s" foi movida para o projeto "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Mover a tarefa para outra coluna quando a data fim estimada for menor que uma quantidade de dias',
@@ -1424,17 +1423,14 @@ return array(
     'Comment' => 'Comentário',
     'Collapse vertically' => 'Contrair verticalmente',
     'Expand vertically' => 'Expandir verticalmente',
-    'MXN - Mexican Peso' => 'Peso mexicano',
-    'Estimated vs actual time per column' => 'Tempo estimado vs tempo real por coluna',
-    'HUF - Hungarian Forint' => 'HUF - Florim húngaro',
+    'MXN - Mexican Peso' => 'MXN - Peso mexicano',
+    'Estimated vs actual time per column' => 'Tempo estimado vs real por coluna',
+    'HUF - Hungarian Forint' => 'HUF - Forint húngaro',
     'XBT - Bitcoin' => 'XBT - Bitcoin',
     'You must select a file to upload as your avatar!' => 'Você deve selecionar um arquivo para enviar como seu avatar!',
-    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'O arquivo enviado não é uma imagem válida! (Apenas *.gif, *.jpg, *.jpeg e *.png são aceitos!)',
-    'Automatically set the due date when the task is moved away from a specific column' => 'Definir data de vencimento automaticamente quando a tarefa sair de determinada coluna',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'O arquivo enviado não é uma imagem válida! (Apenas *.gif, *.jpg, *.jpeg e *.png são permitidos!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Definir automaticamente a data de vencimento quando a tarefa for movida de uma coluna específica',
     'No other projects found.' => 'Nenhum outro projeto encontrado.',
-    'Please choose a project you want to copy the tasks from.' => 'Por favor escolha o projeto de onde você deseja copiar as tarefas.',
-    'Import Tasks' => 'Importar Tarefas',
-    'Copy' => 'Copiar',
     'Tasks copied successfully.' => 'Tarefas copiadas com sucesso.',
     'Unable to copy tasks.' => 'Não foi possível copiar as tarefas.',
     'Theme' => 'Tema',
@@ -1442,28 +1438,34 @@ return array(
     'Light theme' => 'Tema claro',
     'Dark theme' => 'Tema escuro',
     'Automatic theme - Sync with system' => 'Tema automático - Sincronizar com o sistema',
-    'Application managers or more' => 'Gerentes da aplicação ou mais',
+    'Application managers or more' => 'Gerentes de aplicação ou mais',
     'Administrators' => 'Administradores',
     'Visibility:' => 'Visibilidade:',
-    'Standard users' => 'Usuários comuns',
-    'Visibility is required' => 'Visibilidade é obrigatória',
-    'The visibility should be an app role' => 'A visibilidade deve ser uma função da aplicação',
+    'Standard users' => 'Usuários padrão',
+    'Visibility is required' => 'A visibilidade é obrigatória',
+    'The visibility should be an app role' => 'A visibilidade deve ser um papel do aplicativo',
     'Reply' => 'Responder',
-    '%s wrote: ' => '%s escreveu:',
+    '%s wrote: ' => '%s escreveu: ',
     'Number of visible tasks in this column and swimlane' => 'Número de tarefas visíveis nesta coluna e raia',
     'Number of tasks in this swimlane' => 'Número de tarefas nesta raia',
-    'Unable to find another subtask in progress, you can close this window.' => 'Não foi possível encontrar outra subtarefa em progresso, você pode fechar esta janela.',
-    'This theme is invalid' => 'Esse tema não é válido',
-    'This role is invalid' => 'Essa função não é válida',
-    'This timezone is invalid' => 'Esse fuso horário não é válido',
-    'This language is invalid' => 'Esse idioma não é válido',
-    'This URL is invalid' => 'Essa URL não é válida',
+    'Unable to find another subtask in progress, you can close this window.' => 'Não foi possível encontrar outra subtarefa em andamento, você pode fechar esta janela.',
+    'This theme is invalid' => 'Este tema é inválido',
+    'This role is invalid' => 'Este papel é inválido',
+    'This timezone is invalid' => 'Este fuso horário é inválido',
+    'This language is invalid' => 'Este idioma é inválido',
+    'This URL is invalid' => 'Esta URL é inválida',
     'Date format invalid' => 'Formato de data inválido',
-    'Time format invalid' => 'Formato de tempo inválido',
-    'Invalid Mail transport' => 'Transportador de E-mail inválido',
+    'Time format invalid' => 'Formato de hora inválido',
+    'Invalid Mail transport' => 'Transporte de e-mail inválido',
     'Color invalid' => 'Cor inválida',
-    'This value must be greater or equal to %d' => 'Esse valor deve ser maior ou igual a %d',
-    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Adicionar BOM ao início do arquivo (obrigatório para Microsoft Excel)',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'This value must be greater or equal to %d' => 'Este valor deve ser maior ou igual a %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Adicione um BOM no início do arquivo (necessário para o Microsoft Excel)',
+    'Just add these tag(s)' => 'Adicione apenas estas etiquetas',
+    'Remove internal link(s)' => 'Remova os links internos',
+    'Import tasks from another project' => 'Importe tarefas de outro projeto',
+    'Select the project to copy tasks from' => 'Selecione o projeto do qual deseja copiar tarefas',
+    'The total maximum allowed attachments size is %sB.' => 'O tamanho máximo total permitido para anexos é %sB.',
+    'Add attachments' => 'Adicionar anexos',
+    'Task #%d "%s" is overdue' => 'Tarefa #%d "%s" está atrasada',
+    'Enable notifications by default for all new users' => 'Habilitar notificações por padrão para todos os novos usuários',
+];
