@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => ' ',
     'None' => 'Nenhum',
@@ -452,7 +452,7 @@ return array(
     'Timezone:' => 'Fuso horário:',
     'All columns' => 'Todas as colunas',
     'Next' => 'Próximo',
-    // '#%d' => '',
+    '#%d' => '#%d',
     'All swimlanes' => 'Todos os swimlane',
     'All colors' => 'Todas as cores',
     'Moved to column %s' => 'Mover para a coluna %s',
@@ -470,7 +470,7 @@ return array(
     'End' => 'Fim',
     'Task age in days' => 'Idade da tarefa em dias',
     'Days in this column' => 'Dias nesta coluna',
-    // '%dd' => '',
+    '%dd' => '%dd',
     'Add a new link' => 'Adicionar uma nova associação',
     'Do you really want to remove this link: "%s"?' => 'Tem a certeza que quer remover esta associação: "%s"?',
     'Do you really want to remove this link with task #%d?' => 'Tem a certeza que quer remover esta associação com a tarefa n°%d?',
@@ -525,11 +525,11 @@ return array(
     'INR - Indian Rupee' => 'INR - Rúpia Indiana',
     'JPY - Japanese Yen' => 'JPY - Iene Japonês',
     'NZD - New Zealand Dollar' => 'NZD - Dólar Neozelandês',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN – Sol peruano',
     'RSD - Serbian dinar' => 'RSD - Dinar Sérvio',
     'CNY - Chinese Yuan' => 'CNY - Yuan Chinês',
     'USD - US Dollar' => 'USD - Dólar Norte-americano',
-    // 'VES - Venezuelan Bolívar' => '',
+    'VES - Venezuelan Bolívar' => 'VES – Bolívar venezuelano',
     'Destination column' => 'Coluna de destino',
     'Move the task to another column when assigned to a user' => 'Mover a tarefa para uma outra coluna quando esta está atribuída a um utilizador',
     'Move the task to another column when assignee is cleared' => 'Mover a tarefa para uma outra coluna quando esta não está atribuída',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Swimlane alterado na tarefa #%d',
     'Assignee changed on task #%d' => 'Assignado alterado na tarefa #%d',
     '%d overdue tasks' => '%d tarefas em atraso',
-    'Task #%d is overdue' => 'Tarefa #%d está em atraso',
     'No notification.' => 'Sem novas notificações.',
     'Mark all as read' => 'Marcar tudo como lido',
     'Mark as read' => 'Marcar como lido',
@@ -1400,8 +1399,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Reordenar esta coluna por assignado (Z-A)',
     'Reorder this column by due date (ASC)' => 'Reordenar esta coluna por data de vencimento (ASC)',
     'Reorder this column by due date (DESC)' => 'Reordenar esta coluna por data de vencimento (DESC)',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => 'Reordenar esta coluna por id (ASC)',
+    'Reorder this column by id (DESC)' => 'Reordenar esta coluna por id (DESC)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s moveu a tarefa #%d "%s" para o projeto "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Tarefa #%d "%s" foi movida para o projeto "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Mover a tarefa para outra coluna quando a data de vencimento é menos que um certo numero de dias',
@@ -1431,39 +1430,42 @@ return array(
     'You must select a file to upload as your avatar!' => 'Tem selecionar um ficheiro para carregar como seu avatar!',
     'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'O ficheiro que carregou não uma imagem válida! (Apenas *.gif, *.jpg, *.jpeg e *.png são permitidas!)',
     'Automatically set the due date when the task is moved away from a specific column' => 'Definir automaticamente a data de vencimento quando a tarefa for arrastada de uma coluna específica',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'No other projects found.' => 'Nenhum outro projeto encontrado.',
+    'Tasks copied successfully.' => 'Tarefas copiadas com sucesso.',
+    'Unable to copy tasks.' => 'Não foi possível copiar as tarefas.',
+    'Theme' => 'Tema',
+    'Theme:' => 'Tema:',
+    'Light theme' => 'Tema claro',
+    'Dark theme' => 'Tema escuro',
+    'Automatic theme - Sync with system' => 'Tema automático – Sincronizar com o sistema',
+    'Application managers or more' => 'Gestores da aplicação ou superior',
+    'Administrators' => 'Administradores',
+    'Visibility:' => 'Visibilidade:',
+    'Standard users' => 'Utilizadores padrão',
+    'Visibility is required' => 'A visibilidade é obrigatória',
+    'The visibility should be an app role' => 'A visibilidade deve ser um papel da aplicação',
+    'Reply' => 'Responder',
+    '%s wrote: ' => '%s escreveu: ',
+    'Number of visible tasks in this column and swimlane' => 'Número de tarefas visíveis nesta coluna e faixa',
+    'Number of tasks in this swimlane' => 'Número de tarefas nesta faixa',
+    'Unable to find another subtask in progress, you can close this window.' => 'Não foi possível encontrar outra subtarefa em progresso, pode fechar esta janela.',
+    'This theme is invalid' => 'Este tema é inválido',
+    'This role is invalid' => 'Este papel é inválido',
+    'This timezone is invalid' => 'Este fuso horário é inválido',
+    'This language is invalid' => 'Este idioma é inválido',
+    'This URL is invalid' => 'Este URL é inválido',
+    'Date format invalid' => 'Formato de data inválido',
+    'Time format invalid' => 'Formato de hora inválido',
+    'Invalid Mail transport' => 'Transporte de e-mail inválido',
+    'Color invalid' => 'Cor inválida',
+    'This value must be greater or equal to %d' => 'Este valor deve ser maior ou igual a %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Adicionar um BOM no início do ficheiro (necessário para Microsoft Excel)',
+    'Just add these tag(s)' => 'Apenas adicione estas etiquetas',
+    'Remove internal link(s)' => 'Remover ligações internas',
+    'Import tasks from another project' => 'Importar tarefas de outro projeto',
+    'Select the project to copy tasks from' => 'Selecionar o projeto de onde copiar as tarefas',
+    'The total maximum allowed attachments size is %sB.' => 'O tamanho máximo total permitido para anexos é de %sB.',
+    'Add attachments' => 'Adicionar anexos',
+    'Task #%d "%s" is overdue' => 'Tarefa #%d "%s" está atrasada',
+    'Enable notifications by default for all new users' => 'Ativar notificações por padrão para todos os novos usuários',
+];
