@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => '.',
     'number.thousands_separator' => ' ',
     'None' => 'Nimic',
@@ -525,11 +525,11 @@ return array(
     'INR - Indian Rupee' => 'INR - Rupie indiană',
     'JPY - Japanese Yen' => 'JPY - Yen japonez',
     'NZD - New Zealand Dollar' => 'NZD - Dolar neo-zeelandez',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - Sol Peruvian',
     'RSD - Serbian dinar' => 'RSD - Dinar sârbesc',
     'CNY - Chinese Yuan' => 'CNY - Yuan chinez',
     'USD - US Dollar' => 'USD - Dolar american',
-    // 'VES - Venezuelan Bolívar' => '',
+    'VES - Venezuelan Bolívar' => 'VES - Bolívar Venezuelan',
     'Destination column' => 'Coloana destinație',
     'Move the task to another column when assigned to a user' => 'Mută sarcina în altă coloană când este atribuită unui utilizator',
     'Move the task to another column when assignee is cleared' => 'Mută sarcina în altă coloană când este eliberată atribuirea',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Culoarul schimbat pentru sarcina #%d',
     'Assignee changed on task #%d' => 'Persoana desemnată a fost schimbată în sarcina #%d',
     '%d overdue tasks' => '%d sarcini întârziate',
-    'Task #%d is overdue' => 'Sarcina #%d întârzie',
     'No notification.' => 'Fără notificări.',
     'Mark all as read' => 'Marchează toate ca citite',
     'Mark as read' => 'Marchează citit',
@@ -1346,124 +1345,127 @@ return array(
     'Unable to update this template.' => 'Nu am putut actualiza modelul.',
     'Template removed successfully.' => 'Model șters.',
     'Unable to remove this template.' => 'Nu am putut șterge modelul.',
-    // 'Template for the task description' => '',
-    // 'The start date is greater than the end date' => '',
-    // 'Tags must be separated by a comma' => '',
-    // 'Only the task title is required' => '',
-    // 'Creator Username' => '',
-    // 'Color Name' => '',
-    // 'Column Name' => '',
-    // 'Swimlane Name' => '',
-    // 'Time Estimated' => '',
-    // 'Time Spent' => '',
-    // 'External Link' => '',
-    // 'This feature enables the iCal feed, RSS feed and the public board view.' => '',
-    // 'Stop the timer of all subtasks when moving a task to another column' => '',
-    // 'Subtask Title' => '',
-    // 'Add a subtask and activate the timer when moving a task to another column' => '',
-    // 'days' => '',
-    // 'minutes' => '',
-    // 'seconds' => '',
-    // 'Assign automatically a color when preset start date is reached' => '',
-    // 'Move the task to another column once a predefined start date is reached' => '',
-    // 'This task is now linked to the task %s with the relation "%s"' => '',
-    // 'The link with the relation "%s" to the task %s has been removed' => '',
-    // 'Custom Filter:' => '',
-    // 'Unable to find this group.' => '',
-    // '%s moved the task #%d to the column "%s"' => '',
-    // '%s moved the task #%d to the position %d in the column "%s"' => '',
-    // '%s moved the task #%d to the swimlane "%s"' => '',
-    // '%sh spent' => '',
-    // '%sh estimated' => '',
-    // 'Select All' => '',
-    // 'Unselect All' => '',
-    // 'Apply action' => '',
-    // 'Move selected tasks to another column or swimlane' => '',
-    // 'Edit tasks in bulk' => '',
-    // 'Choose the properties that you would like to change for the selected tasks.' => '',
-    // 'Configure this project' => '',
-    // 'Start now' => '',
-    // '%s removed a file from the task #%d' => '',
-    // 'Attachment removed from task #%d: %s' => '',
-    // 'No color' => '',
-    // 'Attachment removed "%s"' => '',
-    // '%s removed a file from the task %s' => '',
-    // 'Move the task to another swimlane when assigned to a user' => '',
-    // 'Destination swimlane' => '',
-    // 'Assign a category when the task is moved to a specific swimlane' => '',
-    // 'Move the task to another swimlane when the category is changed' => '',
-    // 'Reorder this column by priority (ASC)' => '',
-    // 'Reorder this column by priority (DESC)' => '',
-    // 'Reorder this column by assignee and priority (ASC)' => '',
-    // 'Reorder this column by assignee and priority (DESC)' => '',
-    // 'Reorder this column by assignee (A-Z)' => '',
-    // 'Reorder this column by assignee (Z-A)' => '',
-    // 'Reorder this column by due date (ASC)' => '',
-    // 'Reorder this column by due date (DESC)' => '',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
-    // '%s moved the task #%d "%s" to the project "%s"' => '',
-    // 'Task #%d "%s" has been moved to the project "%s"' => '',
-    // 'Move the task to another column when the due date is less than a certain number of days' => '',
-    // 'Automatically update the start date when the task is moved away from a specific column' => '',
-    // 'HTTP Client:' => '',
-    // 'Assigned' => '',
-    // 'Task limits apply to each swimlane individually' => '',
-    // 'Column task limits apply to each swimlane individually' => '',
-    // 'Column task limits are applied to each swimlane individually' => '',
-    // 'Column task limits are applied across swimlanes' => '',
-    // 'Task limit: ' => '',
-    // 'Change to global tag' => '',
-    // 'Do you really want to make the tag "%s" global?' => '',
-    // 'Enable global tags for this project' => '',
-    // 'Group membership(s):' => '',
-    // '%s is a member of the following group(s): %s' => '',
-    // '%d/%d group(s) shown' => '',
-    // 'Subtask creation or modification' => '',
-    // 'Assign the task to a specific user when the task is moved to a specific swimlane' => '',
-    // 'Comment' => '',
-    // 'Collapse vertically' => '',
-    // 'Expand vertically' => '',
-    // 'MXN - Mexican Peso' => '',
-    // 'Estimated vs actual time per column' => '',
-    // 'HUF - Hungarian Forint' => '',
-    // 'XBT - Bitcoin' => '',
-    // 'You must select a file to upload as your avatar!' => '',
-    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'Template for the task description' => 'Șablon pentru descrierea sarcinii',
+    'The start date is greater than the end date' => 'Data de început este mai mare decât data de sfârșit',
+    'Tags must be separated by a comma' => 'Etichetele trebuie separate prin virgulă',
+    'Only the task title is required' => 'Doar titlul sarcinii este obligatoriu',
+    'Creator Username' => 'Nume de utilizator creator',
+    'Color Name' => 'Nume culoare',
+    'Column Name' => 'Nume coloană',
+    'Swimlane Name' => 'Nume culoar',
+    'Time Estimated' => 'Timp estimat',
+    'Time Spent' => 'Timp petrecut',
+    'External Link' => 'Link extern',
+    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Această funcție activează fluxul iCal, fluxul RSS și vizualizarea publică a tabelului.',
+    'Stop the timer of all subtasks when moving a task to another column' => 'Opriți cronometrul tuturor subsarcinilor când mutați o sarcină într-o altă coloană',
+    'Subtask Title' => 'Titlu subsarcină',
+    'Add a subtask and activate the timer when moving a task to another column' => 'Adaugă o subsarcină și activează cronometrul când muți o sarcină într-o altă coloană',
+    'days' => 'zile',
+    'minutes' => 'minute',
+    'seconds' => 'secunde',
+    'Assign automatically a color when preset start date is reached' => 'Atribuiți automat o culoare când se atinge data de începere prestabilită',
+    'Move the task to another column once a predefined start date is reached' => 'Mutați sarcina într-o altă coloană odată ce se atinge o dată de începere predefinită',
+    'This task is now linked to the task %s with the relation "%s"' => 'Această sarcină este acum legată de sarcina %s cu relația "%s"',
+    'The link with the relation "%s" to the task %s has been removed' => 'Legătura cu relația "%s" la sarcina %s a fost eliminată',
+    'Custom Filter:' => 'Filtru personalizat:',
+    'Unable to find this group.' => 'Nu găsesc acest grup.',
+    '%s moved the task #%d to the column "%s"' => '%s a mutat sarcina #%d în coloana "%s"',
+    '%s moved the task #%d to the position %d in the column "%s"' => '%s a mutat sarcina #%d pe poziția %d în coloana "%s"',
+    '%s moved the task #%d to the swimlane "%s"' => '%s a mutat sarcina #%d în culoarul "%s"',
+    '%sh spent' => '%sh petrecute',
+    '%sh estimated' => '%sh estimate',
+    'Select All' => 'Selectează tot',
+    'Unselect All' => 'Deselectează tot',
+    'Apply action' => 'Aplică acțiunea',
+    'Move selected tasks to another column or swimlane' => 'Mutați sarcinile selectate într-o altă coloană sau un alt culoar',
+    'Edit tasks in bulk' => 'Editați sarcinile în masă',
+    'Choose the properties that you would like to change for the selected tasks.' => 'Alegeți proprietățile pe care doriți să le schimbați pentru sarcinile selectate.',
+    'Configure this project' => 'Configurează acest proiect',
+    'Start now' => 'Începe acum',
+    '%s removed a file from the task #%d' => '%s a eliminat un fișier de la sarcina #%d',
+    'Attachment removed from task #%d: %s' => 'Atașament eliminat de la sarcina #%d: %s',
+    'No color' => 'Fără culoare',
+    'Attachment removed "%s"' => 'Atașament eliminat "%s"',
+    '%s removed a file from the task %s' => '%s a eliminat un fișier de la sarcina %s',
+    'Move the task to another swimlane when assigned to a user' => 'Mutați sarcina într-un alt culoar când este atribuită unui utilizator',
+    'Destination swimlane' => 'Culoar destinație',
+    'Assign a category when the task is moved to a specific swimlane' => 'Atribuiți o categorie când sarcina este mutată într-un anumit culoar',
+    'Move the task to another swimlane when the category is changed' => 'Mutați sarcina într-un alt culoar când categoria este schimbată',
+    'Reorder this column by priority (ASC)' => 'Rearanjați această coloană după prioritate (ASC)',
+    'Reorder this column by priority (DESC)' => 'Rearanjați această coloană după prioritate (DESC)',
+    'Reorder this column by assignee and priority (ASC)' => 'Rearanjați această coloană după responsabil și prioritate (ASC)',
+    'Reorder this column by assignee and priority (DESC)' => 'Rearanjați această coloană după responsabil și prioritate (DESC)',
+    'Reorder this column by assignee (A-Z)' => 'Rearanjați această coloană după responsabil (A-Z)',
+    'Reorder this column by assignee (Z-A)' => 'Rearanjați această coloană după responsabil (Z-A)',
+    'Reorder this column by due date (ASC)' => 'Rearanjați această coloană după data scadenței (ASC)',
+    'Reorder this column by due date (DESC)' => 'Rearanjați această coloană după data scadenței (DESC)',
+    'Reorder this column by id (ASC)' => 'Rearanjați această coloană după id (ASC)',
+    'Reorder this column by id (DESC)' => 'Rearanjați această coloană după id (DESC)',
+    '%s moved the task #%d "%s" to the project "%s"' => '%s a mutat sarcina #%d "%s" la proiectul "%s"',
+    'Task #%d "%s" has been moved to the project "%s"' => 'Sarcina #%d "%s" a fost mutată la proiectul "%s"',
+    'Move the task to another column when the due date is less than a certain number of days' => 'Mutați sarcina într-o altă coloană când data scadenței este mai mică de un anumit număr de zile',
+    'Automatically update the start date when the task is moved away from a specific column' => 'Actualizați automat data de începere când sarcina este mutată din o anumită coloană',
+    'HTTP Client:' => 'Client HTTP:',
+    'Assigned' => 'Atribuit',
+    'Task limits apply to each swimlane individually' => 'Limite sarcini se aplică fiecărui culoar individual',
+    'Column task limits apply to each swimlane individually' => 'Limite sarcini coloană se aplică fiecărui culoar individual',
+    'Column task limits are applied to each swimlane individually' => 'Limite sarcini coloană sunt aplicate fiecărui culoar individual',
+    'Column task limits are applied across swimlanes' => 'Limite sarcini coloană sunt aplicate pe toate culoarele',
+    'Task limit: ' => 'Limita sarcini:',
+    'Change to global tag' => 'Schimbă în etichetă globală',
+    'Do you really want to make the tag "%s" global?' => 'Sigur doriți să faceți eticheta "%s" globală?',
+    'Enable global tags for this project' => 'Activează etichetele globale pentru acest proiect',
+    'Group membership(s):' => 'Apartenența la grup(uri):',
+    '%s is a member of the following group(s): %s' => '%s este membru al următorului(lor) grup(uri): %s',
+    '%d/%d group(s) shown' => '%d/%d grup(uri) afișate',
+    'Subtask creation or modification' => 'Creare sau modificare subsarcină',
+    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Atribuiți sarcina unui utilizator specific când sarcina este mutată într-un anumit culoar',
+    'Comment' => 'Comentariu',
+    'Collapse vertically' => 'Strânge vertical',
+    'Expand vertically' => 'Extinde vertical',
+    'MXN - Mexican Peso' => 'MXN - Peso Mexican',
+    'Estimated vs actual time per column' => 'Timp estimat vs timp real pe coloană',
+    'HUF - Hungarian Forint' => 'HUF - Forint Maghiar',
+    'XBT - Bitcoin' => 'XBT - Bitcoin',
+    'You must select a file to upload as your avatar!' => 'Trebuie să selectați un fișier pentru a-l încărca drept avatar!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Fișierul încărcat nu este o imagine validă! (Doar *.gif, *.jpg, *.jpeg și *.png sunt permise!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Setează automat data scadenței când sarcina este mutată dintr-o anumită coloană',
+    'No other projects found.' => 'Nu s-au găsit alte proiecte.',
+    'Tasks copied successfully.' => 'Sarcini copiate cu succes.',
+    'Unable to copy tasks.' => 'Nu se pot copia sarcinile.',
+    'Theme' => 'Temă',
+    'Theme:' => 'Temă:',
+    'Light theme' => 'Temă deschisă',
+    'Dark theme' => 'Temă închisă',
+    'Automatic theme - Sync with system' => 'Temă automată - Sincronizare cu sistemul',
+    'Application managers or more' => 'Manageri aplicație sau mai mult',
+    'Administrators' => 'Administratori',
+    'Visibility:' => 'Vizibilitate:',
+    'Standard users' => 'Utilizatori standard',
+    'Visibility is required' => 'Vizibilitatea este obligatorie',
+    'The visibility should be an app role' => 'Vizibilitatea ar trebui să fie o rolă a aplicației',
+    'Reply' => 'Răspunde',
+    '%s wrote: ' => '%s a scris: ',
+    'Number of visible tasks in this column and swimlane' => 'Număr de sarcini vizibile în această coloană și culoar',
+    'Number of tasks in this swimlane' => 'Număr de sarcini în acest culoar',
+    'Unable to find another subtask in progress, you can close this window.' => 'Nu s-a găsit altă subsarcină în progres, puteți închide această fereastră.',
+    'This theme is invalid' => 'Această temă este nevalidă',
+    'This role is invalid' => 'Acest rol este nevalid',
+    'This timezone is invalid' => 'Acest fus orar este nevalid',
+    'This language is invalid' => 'Această limbă este nevalidă',
+    'This URL is invalid' => 'Această adresă URL este nevalidă',
+    'Date format invalid' => 'Format dată nevalid',
+    'Time format invalid' => 'Format oră nevalid',
+    'Invalid Mail transport' => 'Transport Mail nevalid',
+    'Color invalid' => 'Culoare nevalidă',
+    'This value must be greater or equal to %d' => 'Această valoare trebuie să fie mai mare sau egală cu %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Adăugați un BOM la începutul fișierului (necesar pentru Microsoft Excel)',
+    'Just add these tag(s)' => 'Doar adăugați aceste etichetă(e)',
+    'Remove internal link(s)' => 'Elimină legătură(i) internă(e)',
+    'Import tasks from another project' => 'Importă sarcini dintr-un alt proiect',
+    'Select the project to copy tasks from' => 'Selectați proiectul din care să copiați sarcinile',
+    'The total maximum allowed attachments size is %sB.' => 'Dimensiunea totală maximă permisă pentru atașamente este %sB.',
+    'Add attachments' => 'Adaugă atașamente',
+    'Task #%d "%s" is overdue' => 'Sarcina #%d "%s" este întârziată',
+    'Enable notifications by default for all new users' => 'Activează notificările implicit pentru toți utilizatorii noi',
+];
