@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => ' ',
     'None' => 'Žiadne',
@@ -525,7 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR – Indická rupia',
     'JPY - Japanese Yen' => 'JPY – Japonský jen',
     'NZD - New Zealand Dollar' => 'NZD – Novozélandský dolár',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN – peruánsky sol',
     'RSD - Serbian dinar' => 'RSD – Srbský dinár',
     'CNY - Chinese Yuan' => 'CNY – Čínsky juan',
     'USD - US Dollar' => 'USD – Americký dolár',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Zmenená dráha úlohy #%d',
     'Assignee changed on task #%d' => 'Zmenené pridelenie úlohy #%d',
     '%d overdue tasks' => '%d úloh po termíne',
-    'Task #%d is overdue' => 'Úloha #%d je po termíne',
     'No notification.' => 'Žiadne upozornenia.',
     'Mark all as read' => 'Označiť všetky ako prečítané',
     'Mark as read' => 'Označiť ako prečítané',
@@ -1400,8 +1399,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Zoradiť stĺpec podľa pridelenia (Z-A)',
     'Reorder this column by due date (ASC)' => 'Zoradiť stĺpec podľa termínu ukončenia (VZOST)',
     'Reorder this column by due date (DESC)' => 'Zoradiť stĺpec podľa termínu ukončenia (ZOST)',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => 'Zoradiť tento stĺpec podľa ID (vzostupne)',
+    'Reorder this column by id (DESC)' => 'Zoradiť tento stĺpec podľa ID (zostupne)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s presunul/a úlohu č. %d „%s” do projektu „%s”',
     'Task #%d "%s" has been moved to the project "%s"' => 'Úloha č. %d „%s” bola presunutá do projektu „%s”',
     'Move the task to another column when the due date is less than a certain number of days' => 'Presunúť úlohu do iného stĺpca, keď je do termínu ukončenia menej ako zadaný počet dní',
@@ -1430,40 +1429,43 @@ return array(
     'XBT - Bitcoin' => 'XBT – Bitcoin',
     'You must select a file to upload as your avatar!' => 'Musíte zvoliť súbor na nahratie ako svoj avatar',
     'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'nahraný súbor nie je paltný obrázok! (Povolené sú len *.gif, *.jpg, *.jpeg a *.png!)',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'Automatically set the due date when the task is moved away from a specific column' => 'Automaticky nastaviť termín úlohy po presunutí z určitého stĺpca',
+    'No other projects found.' => 'Nenašli sa žiadne ďalšie projekty.',
+    'Tasks copied successfully.' => 'Úlohy boli úspešne skopírované.',
+    'Unable to copy tasks.' => 'Úlohy sa nepodarilo skopírovať.',
+    'Theme' => 'Téma',
+    'Theme:' => 'Téma:',
+    'Light theme' => 'Svetlá téma',
+    'Dark theme' => 'Tmavá téma',
+    'Automatic theme - Sync with system' => 'Automatická téma – synchronizácia so systémom',
+    'Application managers or more' => 'Správcovia aplikácie alebo vyššie',
+    'Administrators' => 'Administrátori',
+    'Visibility:' => 'Viditeľnosť:',
+    'Standard users' => 'Štandardní používatelia',
+    'Visibility is required' => 'Viditeľnosť je povinná',
+    'The visibility should be an app role' => 'Viditeľnosť musí byť rolou v aplikácii',
+    'Reply' => 'Odpovedať',
+    '%s wrote: ' => '%s napísal(a): ',
+    'Number of visible tasks in this column and swimlane' => 'Počet viditeľných úloh v tomto stĺpci a plaveckom pruhu',
+    'Number of tasks in this swimlane' => 'Počet úloh v tomto plaveckom pruhu',
+    'Unable to find another subtask in progress, you can close this window.' => 'Nepodarilo sa nájsť ďalšiu podúlohu v priebehu, môžete zavrieť toto okno.',
+    'This theme is invalid' => 'Táto téma je neplatná',
+    'This role is invalid' => 'Táto rola je neplatná',
+    'This timezone is invalid' => 'Toto časové pásmo je neplatné',
+    'This language is invalid' => 'Tento jazyk je neplatný',
+    'This URL is invalid' => 'Tento URL je neplatný',
+    'Date format invalid' => 'Neplatný formát dátumu',
+    'Time format invalid' => 'Neplatný formát času',
+    'Invalid Mail transport' => 'Neplatný spôsob odosielania e-mailov',
+    'Color invalid' => 'Neplatná farba',
+    'This value must be greater or equal to %d' => 'Táto hodnota musí byť väčšia alebo rovná %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Pridať BOM na začiatok súboru (vyžaduje Microsoft Excel)',
+    'Just add these tag(s)' => 'Len pridajte tieto značky',
+    'Remove internal link(s)' => 'Odstrániť interné odkazy',
+    'Import tasks from another project' => 'Importovať úlohy z iného projektu',
+    'Select the project to copy tasks from' => 'Vyberte projekt, z ktorého chcete kopírovať úlohy',
+    'The total maximum allowed attachments size is %sB.' => 'Celková maximálna povolená veľkosť príloh je %sB.',
+    'Add attachments' => 'Pridať prílohy',
+    'Task #%d "%s" is overdue' => 'Úloha #%d „%s” je po termíne',
+    'Enable notifications by default for all new users' => 'Predvolene zapnúť upozornenia pre všetkých nových používateľov',
+];
