@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => '.',
     'None' => 'Nijedan',
@@ -525,7 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Indijski rupi',
     'JPY - Japanese Yen' => 'JPY - Japanski jen',
     'NZD - New Zealand Dollar' => 'NZD - Novozelandski dolar',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - peruanski sol',
     'RSD - Serbian dinar' => 'RSD - Srpski dinar',
     'CNY - Chinese Yuan' => 'CNY - Kineski jen',
     'USD - US Dollar' => 'USD - Američki dolar',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Staza je promenjena za zadatak #%d',
     'Assignee changed on task #%d' => 'Izvršilac je promenjen na zadatku #%d',
     '%d overdue tasks' => '%d zadataka kasni',
-    'Task #%d is overdue' => 'Zadatak #%d kasni',
     'No notification.' => 'Nema novih obaveštenja.',
     'Mark all as read' => 'Označi sve kao pročitano',
     'Mark as read' => 'Označi kao pročitano',
@@ -1432,9 +1431,6 @@ return array(
     'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Datoteka koju ste otpremili nije validna slika! (Dozvoljeni su samo *.gif, *.jpg, *.jpeg i *.png formati!)',
     'Automatically set the due date when the task is moved away from a specific column' => 'Automatski postavite rok završetka kada se zadatak premesti iz određene kolone',
     'No other projects found.' => 'Nisu pronađeni drugi projekti.',
-    'Please choose a project you want to copy the tasks from.' => 'Molimo izaberite projekat iz kojeg želite da kopirate zadatke.',
-    'Import Tasks' => 'Uvoz zadatka',
-    'Copy' => 'Kopiraj',
     'Tasks copied successfully.' => 'Zadaci su uspešno iskopirani.',
     'Unable to copy tasks.' => 'Nije moguće kopirati zadatke.',
     'Theme' => 'Tema',
@@ -1442,28 +1438,34 @@ return array(
     'Light theme' => 'Svetla tema',
     'Dark theme' => 'Tamna tema',
     'Automatic theme - Sync with system' => 'Automatska tema - sinhronizacija sa sistemom',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'Application managers or more' => 'Menadžeri aplikacije ili više',
+    'Administrators' => 'Administratori',
+    'Visibility:' => 'Vidljivost:',
+    'Standard users' => 'Standardni korisnici',
+    'Visibility is required' => 'Vidljivost je obavezna',
+    'The visibility should be an app role' => 'Vidljivost treba da bude uloga aplikacije',
+    'Reply' => 'Odgovori',
+    '%s wrote: ' => '%s je napisao/la: ',
+    'Number of visible tasks in this column and swimlane' => 'Broj vidljivih zadataka u ovoj koloni i plivačkoj stazi',
+    'Number of tasks in this swimlane' => 'Broj zadataka u ovoj plivačkoj stazi',
+    'Unable to find another subtask in progress, you can close this window.' => 'Nije moguće pronaći drugi podzadatak u toku, možete zatvoriti ovaj prozor.',
+    'This theme is invalid' => 'Ova tema nije validna',
+    'This role is invalid' => 'Ova uloga nije validna',
+    'This timezone is invalid' => 'Ova vremenska zona nije validna',
+    'This language is invalid' => 'Ovaj jezik nije validan',
+    'This URL is invalid' => 'Ovaj URL nije validan',
+    'Date format invalid' => 'Format datuma nije validan',
+    'Time format invalid' => 'Format vremena nije validan',
+    'Invalid Mail transport' => 'Neispravan način slanja pošte',
+    'Color invalid' => 'Neispravna boja',
+    'This value must be greater or equal to %d' => 'Ova vrednost mora biti veća ili jednaka %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Dodaj BOM na početak fajla (potrebno za Microsoft Excel)',
+    'Just add these tag(s)' => 'Samo dodaj ove oznake',
+    'Remove internal link(s)' => 'Ukloni interne linkove',
+    'Import tasks from another project' => 'Uvezi zadatke iz drugog projekta',
+    'Select the project to copy tasks from' => 'Izaberi projekat iz kog želiš da kopiraš zadatke',
+    'The total maximum allowed attachments size is %sB.' => 'Ukupna dozvoljena veličina priloga je %sB.',
+    'Add attachments' => 'Dodaj priloge',
+    'Task #%d "%s" is overdue' => 'Zadatak #%d "%s" je s iztečen rok',
+    'Enable notifications by default for all new users' => 'Omogući notifikacije po difoltu za sve nove korisnike',
+];
