@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => ',',
     'number.thousands_separator' => ' ',
     'None' => 'Ingen',
@@ -525,7 +525,7 @@ return array(
     'INR - Indian Rupee' => 'INR - Indiska rupier',
     'JPY - Japanese Yen' => 'JPY - Japanska yen',
     'NZD - New Zealand Dollar' => 'NZD - Nya Zeeländska dollar',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN – Peruansk sol',
     'RSD - Serbian dinar' => 'RSD - Serbiska dinarer',
     'CNY - Chinese Yuan' => 'CNY - Kinesisk yuan',
     'USD - US Dollar' => 'USD - Amerikanska dollar',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => 'Simbana uppdaterad för uppgift #%d',
     'Assignee changed on task #%d' => 'Uppgiftsinnehavare ändrades på uppgift #%d',
     '%d overdue tasks' => '%d försenade uppgifter',
-    'Task #%d is overdue' => 'Uppgift #%d är försenad',
     'No notification.' => 'Ingen notifiering',
     'Mark all as read' => 'Markera alla som lästa',
     'Mark as read' => 'Markera som läst',
@@ -1149,40 +1148,40 @@ return array(
     'Remove this role' => 'Ta bort denna rollen',
     'There is no restriction for this role.' => 'Det finns inga restriktioner för denna rollen',
     'Only moving task between those columns is permitted' => 'Endast tillåtet att flytta uppgifter mellan dessa kolumner',
-    // 'Close a task in a specific column when not moved during a given period' => '',
-    // 'Edit columns' => '',
-    // 'The column restriction has been created successfully.' => '',
-    // 'Unable to create this column restriction.' => '',
-    // 'Column restriction removed successfully.' => '',
-    // 'Unable to remove this restriction.' => '',
-    // 'Your custom project role has been created successfully.' => '',
-    // 'Unable to create custom project role.' => '',
-    // 'Your custom project role has been updated successfully.' => '',
-    // 'Unable to update custom project role.' => '',
-    // 'Custom project role removed successfully.' => '',
-    // 'Unable to remove this project role.' => '',
-    // 'The project restriction has been created successfully.' => '',
-    // 'Unable to create this project restriction.' => '',
-    // 'Project restriction removed successfully.' => '',
-    // 'You cannot create tasks in this column.' => '',
-    // 'Task creation is permitted for this column' => '',
-    // 'Closing or opening a task is permitted for this column' => '',
-    // 'Task creation is blocked for this column' => '',
-    // 'Closing or opening a task is blocked for this column' => '',
-    // 'Task creation is not permitted' => '',
-    // 'Closing or opening a task is not permitted' => '',
-    // 'New drag and drop restriction for the role "%s"' => '',
-    // 'People belonging to this role will be able to move tasks only between the source and the destination column.' => '',
-    // 'Remove a column restriction' => '',
-    // 'Do you really want to remove this column restriction: "%s" to "%s"?' => '',
-    // 'New column restriction for the role "%s"' => '',
-    // 'Rule' => '',
-    // 'Do you really want to remove this column restriction?' => '',
-    // 'Custom roles' => '',
-    // 'New custom project role' => '',
-    // 'Edit custom project role' => '',
-    // 'Remove a custom role' => '',
-    // 'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => '',
+    'Close a task in a specific column when not moved during a given period' => 'Stäng en uppgift i en specifik kolumn om den inte flyttas under en viss period',
+    'Edit columns' => 'Redigera kolumner',
+    'The column restriction has been created successfully.' => 'Kolumnbegränsningen har skapats.',
+    'Unable to create this column restriction.' => 'Det gick inte att skapa denna kolumnbegränsning.',
+    'Column restriction removed successfully.' => 'Kolumnbegränsningen har tagits bort.',
+    'Unable to remove this restriction.' => 'Det gick inte att ta bort denna begränsning.',
+    'Your custom project role has been created successfully.' => 'Din anpassade projektroll har skapats.',
+    'Unable to create custom project role.' => 'Det gick inte att skapa anpassad projektroll.',
+    'Your custom project role has been updated successfully.' => 'Din anpassade projektroll har uppdaterats.',
+    'Unable to update custom project role.' => 'Det gick inte att uppdatera anpassad projektroll.',
+    'Custom project role removed successfully.' => 'Anpassad projektroll har tagits bort.',
+    'Unable to remove this project role.' => 'Det gick inte att ta bort denna projektroll.',
+    'The project restriction has been created successfully.' => 'Projektbegränsningen har skapats.',
+    'Unable to create this project restriction.' => 'Det gick inte att skapa denna projektbegränsning.',
+    'Project restriction removed successfully.' => 'Projektbegränsningen har tagits bort.',
+    'You cannot create tasks in this column.' => 'Du kan inte skapa uppgifter i denna kolumn.',
+    'Task creation is permitted for this column' => 'Uppgiftsskapande är tillåtet för denna kolumn',
+    'Closing or opening a task is permitted for this column' => 'Att stänga eller öppna en uppgift är tillåtet för denna kolumn',
+    'Task creation is blocked for this column' => 'Uppgiftsskapande är blockerat för denna kolumn',
+    'Closing or opening a task is blocked for this column' => 'Att stänga eller öppna en uppgift är blockerat för denna kolumn',
+    'Task creation is not permitted' => 'Uppgiftsskapande är inte tillåtet',
+    'Closing or opening a task is not permitted' => 'Att stänga eller öppna en uppgift är inte tillåtet',
+    'New drag and drop restriction for the role "%s"' => 'Ny dra-och-släpp-begränsning för rollen "%s"',
+    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Personer med denna roll kan endast flytta uppgifter mellan käll- och destinationskolumnen.',
+    'Remove a column restriction' => 'Ta bort en kolumnbegränsning',
+    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Vill du verkligen ta bort denna kolumnbegränsning: "%s" till "%s"?',
+    'New column restriction for the role "%s"' => 'Ny kolumnbegränsning för rollen "%s"',
+    'Rule' => 'Regel',
+    'Do you really want to remove this column restriction?' => 'Vill du verkligen ta bort denna kolumnbegränsning?',
+    'Custom roles' => 'Anpassade roller',
+    'New custom project role' => 'Ny anpassad projektroll',
+    'Edit custom project role' => 'Redigera anpassad projektroll',
+    'Remove a custom role' => 'Ta bort en anpassad roll',
+    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Vill du verkligen ta bort denna anpassade roll: "%s"? Alla personer tilldelade denna roll kommer att bli projektmedlemmar.',
     'There is no custom role for this project.' => 'Det finns ingen anpassad roll för detta projekt.',
     'New project restriction for the role "%s"' => 'Ny projektrestriktion för roll "%s"',
     'Restriction' => 'Restriktion',
@@ -1400,8 +1399,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Ändra ordning i denna kolumnen enligt tilldelning (Z-A)',
     'Reorder this column by due date (ASC)' => 'Ändra ordning i denna kolumnen enligt förfallodatum (stigande)',
     'Reorder this column by due date (DESC)' => 'Ändra ordning i denna kolumnen enligt förfallodatum (fallande)',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => 'Sortera denna kolumn efter ID (stigande)',
+    'Reorder this column by id (DESC)' => 'Sortera denna kolumn efter ID (fallande)',
     '%s moved the task #%d "%s" to the project "%s"' => '%s flyttade uppgift #%d "%s" till projektet "%s"',
     'Task #%d "%s" has been moved to the project "%s"' => 'Uppgift #%d "%s" har flyttats till projektet "%s"',
     'Move the task to another column when the due date is less than a certain number of days' => 'Flytta uppgiften till en annan kolumn när förfallodatum är närmare än ett visst antal dagar',
@@ -1427,43 +1426,46 @@ return array(
     'MXN - Mexican Peso' => 'MXN - Mexikansk peso',
     'Estimated vs actual time per column' => 'Uppskattad kontra faktisk tid per kolumn',
     'HUF - Hungarian Forint' => 'HUF - Ungersk forint',
-    // 'XBT - Bitcoin' => '',
+    'XBT - Bitcoin' => 'XBT – Bitcoin',
     'You must select a file to upload as your avatar!' => 'Du måste välja en fil att uppladda som din avatar!',
     'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Filen du laddade upp är inte ett giltigt bildformat! (Endast *.gif *.jpg *.jpeg samt *.png är tillåtet!)',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'Automatically set the due date when the task is moved away from a specific column' => 'Ställ automatiskt in förfallodatum när uppgiften flyttas från en specifik kolumn',
+    'No other projects found.' => 'Inga andra projekt hittades.',
+    'Tasks copied successfully.' => 'Uppgifter kopierades framgångsrikt.',
+    'Unable to copy tasks.' => 'Det gick inte att kopiera uppgifter.',
+    'Theme' => 'Tema',
+    'Theme:' => 'Tema:',
+    'Light theme' => 'Ljust tema',
+    'Dark theme' => 'Mörkt tema',
+    'Automatic theme - Sync with system' => 'Automatiskt tema – synkronisera med systemet',
+    'Application managers or more' => 'Applikationsansvariga eller högre',
+    'Administrators' => 'Administratörer',
+    'Visibility:' => 'Synlighet:',
+    'Standard users' => 'Standardanvändare',
+    'Visibility is required' => 'Synlighet krävs',
+    'The visibility should be an app role' => 'Synligheten bör vara en applikationsroll',
+    'Reply' => 'Svara',
+    '%s wrote: ' => '%s skrev: ',
+    'Number of visible tasks in this column and swimlane' => 'Antal synliga uppgifter i denna kolumn och simlinje',
+    'Number of tasks in this swimlane' => 'Antal uppgifter i denna simlinje',
+    'Unable to find another subtask in progress, you can close this window.' => 'Kunde inte hitta en annan deluppgift i gång, du kan stänga detta fönster.',
+    'This theme is invalid' => 'Detta tema är ogiltigt',
+    'This role is invalid' => 'Denna roll är ogiltig',
+    'This timezone is invalid' => 'Denna tidszon är ogiltig',
+    'This language is invalid' => 'Detta språk är ogiltigt',
+    'This URL is invalid' => 'Denna URL är ogiltig',
+    'Date format invalid' => 'Ogiltigt datumformat',
+    'Time format invalid' => 'Ogiltigt tidsformat',
+    'Invalid Mail transport' => 'Ogiltig e-posttransport',
+    'Color invalid' => 'Ogiltig färg',
+    'This value must be greater or equal to %d' => 'Detta värde måste vara större än eller lika med %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Lägg till en BOM i början av filen (krävs för Microsoft Excel)',
+    'Just add these tag(s)' => 'Lägg bara till dessa taggar',
+    'Remove internal link(s)' => 'Ta bort interna länkar',
+    'Import tasks from another project' => 'Importera uppgifter från ett annat projekt',
+    'Select the project to copy tasks from' => 'Välj projektet att kopiera uppgifter från',
+    'The total maximum allowed attachments size is %sB.' => 'Den totala maximalt tillåtna bilagestorleken är %sB.',
+    'Add attachments' => 'Lägg till bilagor',
+    'Task #%d "%s" is overdue' => 'Uppgift #%d "%s" är försenad',
+    'Enable notifications by default for all new users' => 'Aktivera notifieringar som standard för alla nya användare',
+];
