@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => '.',
     'number.thousands_separator' => ',',
     'None' => 'Hiçbiri',
@@ -525,11 +525,11 @@ return array(
     'INR - Indian Rupee' => 'INR - Hint Rupesi',
     'JPY - Japanese Yen' => 'JPY - Japon Yeni',
     'NZD - New Zealand Dollar' => 'NZD - Yeni Zelanda Doları',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - Peru Solü',
     'RSD - Serbian dinar' => 'Sırp Dinarı',
-    'CNY - Chinese Yuan' => 'Çin Yuanı',
+    'CNY - Chinese Yuan' => 'CNY - Çin Yuanı',
     'USD - US Dollar' => 'USD Amerikan Doları',
-    // 'VES - Venezuelan Bolívar' => '',
+    'VES - Venezuelan Bolívar' => 'VES - Venezuela Bolivarı',
     'Destination column' => 'Hedef Sütun',
     'Move the task to another column when assigned to a user' => 'Bir kullanıcıya atandığında görevi başka bir sütuna taşı',
     'Move the task to another column when assignee is cleared' => 'Atanmış kullanıcı kaldırıldığında görevi başka bir sütuna taşı',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => '#%d görevinin kulvarı değişti',
     'Assignee changed on task #%d' => '#%d görevine atanan değişti',
     '%d overdue tasks' => '%d gecikmiş görev',
-    'Task #%d is overdue' => '#%d görevi gecikti',
     'No notification.' => 'Yeni bildirim yok.',
     'Mark all as read' => 'Tümünü okunmuş olarak işaretle',
     'Mark as read' => 'Okunmuş olarak işaretle',
@@ -1400,8 +1399,8 @@ return array(
     'Reorder this column by assignee (Z-A)' => 'Kolonu atanana göre azalan sırala (Z-A)',
     'Reorder this column by due date (ASC)' => 'Kolonu hedef tarihe göre artan sırala',
     'Reorder this column by due date (DESC)' => 'Kolonu hedef tarihe göre azalan sırala',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
+    'Reorder this column by id (ASC)' => 'Kolonu id ye göre artan sırala',
+    'Reorder this column by id (DESC)' => 'Kolonu id ye göre azalan sırala',
     '%s moved the task #%d "%s" to the project "%s"' => '%s görevi taşıdı #%d "%s" "%s" projesine',
     'Task #%d "%s" has been moved to the project "%s"' => 'Görev #%d "%s" tarafından "%s" projesine taşındı',
     'Move the task to another column when the due date is less than a certain number of days' => 'Hedef tarihe belirli bir gün sayısından az kaldığında görevi başka kolona taşı',
@@ -1420,50 +1419,53 @@ return array(
     '%s is a member of the following group(s): %s' => '"%s" şu grupların üyesidir:"%s"',
     '%d/%d group(s) shown' => '%d/%dgrupları göster',
     'Subtask creation or modification' => 'Alt görev oluşturma veya değiştirme',
-    // 'Assign the task to a specific user when the task is moved to a specific swimlane' => '',
-    // 'Comment' => '',
-    // 'Collapse vertically' => '',
-    // 'Expand vertically' => '',
-    // 'MXN - Mexican Peso' => '',
-    // 'Estimated vs actual time per column' => '',
-    // 'HUF - Hungarian Forint' => '',
+    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Görev belirli bir kulvara taşındığında belirli bir kullanıcıya ata',
+    'Comment' => 'Yorum',
+    'Collapse vertically' => 'Dikey olarak daralt',
+    'Expand vertically' => 'Dikey olarak genişlet',
+    'MXN - Mexican Peso' => 'MXN - Meksika Pesosu',
+    'Estimated vs actual time per column' => 'Sütun başına tahmini ve gerçek zaman',
+    'HUF - Hungarian Forint' => 'HUF - Macar Forinti',
     'XBT - Bitcoin' => 'XBT - Bitcoin',
-    // 'You must select a file to upload as your avatar!' => '',
-    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'You must select a file to upload as your avatar!' => 'Avatarınız olarak yüklemek için bir dosya seçmelisiniz!',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Yüklediğiniz dosya geçerli bir resim değil! (Yalnızca *.gif, *.jpg, *.jpeg ve *.png dosyalarına izin verilir!)',
+    'Automatically set the due date when the task is moved away from a specific column' => 'Görev belirli bir sütundan taşındığında son tarihi otomatik olarak ayarla',
+    'No other projects found.' => 'Başka proje bulunamadı.',
+    'Tasks copied successfully.' => 'Görevler başarıyla kopyalandı.',
+    'Unable to copy tasks.' => 'Görevler kopyalanamıyor.',
+    'Theme' => 'Tema',
+    'Theme:' => 'Tema:',
+    'Light theme' => 'Açık tema',
+    'Dark theme' => 'Koyu tema',
+    'Automatic theme - Sync with system' => 'Otomatik tema - Sistemle senkronize et',
+    'Application managers or more' => 'Uygulama yöneticileri veya daha fazlası',
+    'Administrators' => 'Yöneticiler',
+    'Visibility:' => 'Görünürlük:',
+    'Standard users' => 'Standart kullanıcılar',
+    'Visibility is required' => 'Görünürlük gereklidir',
+    'The visibility should be an app role' => 'Görünürlük bir uygulama rolü olmalıdır',
+    'Reply' => 'Yanıtla',
+    '%s wrote: ' => '%s yazdı: ',
+    'Number of visible tasks in this column and swimlane' => 'Bu sütun ve yüzme yolunda görünen görev sayısı',
+    'Number of tasks in this swimlane' => 'Bu yüzme yolundaki görev sayısı',
+    'Unable to find another subtask in progress, you can close this window.' => 'Devam eden başka bir alt görev bulunamadı, bu pencereyi kapatabilirsiniz.',
+    'This theme is invalid' => 'Bu tema geçersiz',
+    'This role is invalid' => 'Bu rol geçersiz',
+    'This timezone is invalid' => 'Bu saat dilimi geçersiz',
+    'This language is invalid' => 'Bu dil geçersiz',
+    'This URL is invalid' => 'Bu URL geçersiz',
+    'Date format invalid' => 'Tarih biçimi geçersiz',
+    'Time format invalid' => 'Saat biçimi geçersiz',
+    'Invalid Mail transport' => 'Geçersiz posta aktarımı',
+    'Color invalid' => 'Geçersiz renk',
+    'This value must be greater or equal to %d' => 'Bu değer %d veya daha büyük olmalıdır',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Dosyanın başına BOM ekle (Microsoft Excel için gereklidir)',
+    'Just add these tag(s)' => 'Sadece bu etiketleri ekle',
+    'Remove internal link(s)' => 'Dahili bağlantıları kaldır',
+    'Import tasks from another project' => 'Başka bir projeden görevleri içe aktar',
+    'Select the project to copy tasks from' => 'Görevleri kopyalamak için projeyi seçin',
+    'The total maximum allowed attachments size is %sB.' => 'Ekler için izin verilen toplam maksimum boyut %sB.',
+    'Add attachments' => 'Ekleri ekle',
+    'Task #%d "%s" is overdue' => 'Görev #%d "%s" son tarihi geçti',
+    'Enable notifications by default for all new users' => 'Tüm yeni kullanıcılar için bildirimleri varsayılan olarak etkinleştir',
+];
