@@ -1,6 +1,6 @@
 <?php
 
-return array(
+return [
     'number.decimals_separator' => '.',
     'number.thousands_separator' => ',',
     'None' => '無',
@@ -525,11 +525,11 @@ return array(
     'INR - Indian Rupee' => '印度盧比',
     'JPY - Japanese Yen' => '日元',
     'NZD - New Zealand Dollar' => '紐西蘭元',
-    // 'PEN - Peruvian Sol' => '',
+    'PEN - Peruvian Sol' => 'PEN - 秘鲁索尔',
     'RSD - Serbian dinar' => '第納爾',
     'CNY - Chinese Yuan' => '人民幣',
     'USD - US Dollar' => '美元',
-    // 'VES - Venezuelan Bolívar' => '',
+    'VES - Venezuelan Bolívar' => 'VES - 委內瑞拉玻利瓦爾',
     'Destination column' => '目標欄位',
     'Move the task to another column when assigned to a user' => '指定負責人時移動到其它欄位',
     'Move the task to another column when assignee is cleared' => '移除負責人時移動到其它欄位',
@@ -647,7 +647,7 @@ return array(
     'Only for tasks assigned to me' => '所有指派给我的任務',
     'Only for tasks created by me' => '所有我建立的任務',
     'Only for tasks created by me and tasks assigned to me' => '所有我建立的並且指派给我的任務',
-    // '%%Y-%%m-%%d' => '',
+    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
     'Total for all columns' => '所有欄位下的',
     'You need at least 2 days of data to show the chart.' => '柱狀圖至少需要2天的資料。',
     '<15m' => '小於15分鐘',
@@ -692,7 +692,7 @@ return array(
     'Average cycle time: ' => '平均周期時間: ',
     'Cycle Time' => '週期時間',
     'Lead Time' => '工作時間',
-    // 'This chart shows the average lead and cycle time for the last %d tasks over the time.' => '',
+    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => '目前柱狀圖表示最新%d條任務的平均工作時間和週期時間',
     'Average time into each column' => '每個任務欄的平均時間',
     'Lead and cycle time' => '工作時間和週期時間',
     'Lead time: ' => '工作時間: ',
@@ -769,7 +769,6 @@ return array(
     'Swimlane changed for task #%d' => '任務#%d的里程碑已改變',
     'Assignee changed on task #%d' => '任務#%d的指派人已改變',
     '%d overdue tasks' => '%d條逾期任務',
-    'Task #%d is overdue' => '任務#%d已逾期',
     'No notification.' => '没有新通知',
     'Mark all as read' => '標記所有為已讀',
     'Mark as read' => '標記為已讀',
@@ -1255,23 +1254,23 @@ return array(
     'This project is open' => '專案已打開',
     'This project is closed' => '專案已關閉',
     'Unable to upload files, check the permissions of your data folder.' => '無法上傳文件，請檢查你的data目錄權限。',
-    // 'Another category with the same name exists in this project' => '',
-    // 'Comment sent by email successfully.' => '',
-    // 'Sent by email to "%s" (%s)' => '',
-    // 'Unable to read uploaded file.' => '',
-    // 'Database uploaded successfully.' => '',
-    // 'Task sent by email successfully.' => '',
+    'Another category with the same name exists in this project' => '此项目中存在另一个同名类别',
+    'Comment sent by email successfully.' => '評論已成功通過電子郵件發送。',
+    'Sent by email to "%s" (%s)' => '通過電子郵件發送給 "%s" (%s)',
+    'Unable to read uploaded file.' => '無法讀取上傳的檔案。',
+    'Database uploaded successfully.' => '資料庫成功上傳。',
+    'Task sent by email successfully.' => '任務已成功通過電子郵件發送。',
     'There is no category in this project.' => '目前專案没有分類。',
     'Send by email' => '發送郵件',
     'Create and send a comment by email' => '通過電子郵件建立和發送評論',
     'Subject' => '主旨',
-    // 'Upload the database' => '',
-    // 'You could upload the previously downloaded Sqlite database (Gzip format).' => '',
-    // 'Database file' => '',
-    // 'Upload' => '',
-    // 'Your project must have at least one active swimlane.' => '',
-    // 'Project: %s' => '',
-    // 'Automatic action not found: "%s"' => '',
+    'Upload the database' => '上傳資料庫',
+    'You could upload the previously downloaded Sqlite database (Gzip format).' => '您可以上傳之前下載的 Sqlite 資料庫 (Gzip 格式)。',
+    'Database file' => '資料庫檔案',
+    'Upload' => '上傳',
+    'Your project must have at least one active swimlane.' => '您的專案必須至少有一個作用中的泳道。',
+    'Project: %s' => '專案：%s',
+    'Automatic action not found: "%s"' => '找不到自動動作: "%s"',
     '%d projects' => '%d 專案',
     '%d project' => '%d 專案',
     'There is no project.' => '目前没有專案。',
@@ -1283,187 +1282,190 @@ return array(
     '%d tasks' => '%d 任務',
     '%d task' => '%d 任務',
     'Task ID' => '任務編號',
-    // 'Assign automatically a color when due date is expired' => '',
-    // 'Total score in this column across all swimlanes' => '',
-    // 'HRK - Kuna' => '',
-    // 'ARS - Argentine Peso' => '',
-    // 'COP - Colombian Peso' => '',
+    'Assign automatically a color when due date is expired' => '當截止日期過期時自動分配顏色',
+    'Total score in this column across all swimlanes' => '此列所有泳道的總分數',
+    'HRK - Kuna' => 'HRK - 克羅埃西亞庫納',
+    'ARS - Argentine Peso' => 'ARS - 阿根廷比索',
+    'COP - Colombian Peso' => 'COP - 哥倫比亞比索',
     '%d groups' => '%d 群組',
     '%d group' => '%d 群組',
     'Group ID' => '群組編號',
-    // 'External ID' => '',
+    'External ID' => '外部 ID',
     '%d users' => '%d 使用者',
     '%d user' => '%d 使用者',
     'Hide subtasks' => '顯示子任務',
     'Show subtasks' => '隱藏子任務',
-    // 'Authentication Parameters' => '',
-    // 'API Access' => '',
-    // 'No users found.' => '',
+    'Authentication Parameters' => '認證參數',
+    'API Access' => 'API 存取',
+    'No users found.' => '找不到使用者。',
     'User ID' => '使用者編號',
-    // 'Notifications are activated' => '',
-    // 'Notifications are disabled' => '',
+    'Notifications are activated' => '通知已啟用',
+    'Notifications are disabled' => '通知已停用',
     'User disabled' => '帳號已禁用',
     '%d notifications' => '%d 通知',
     '%d notification' => '%d 通知',
-    // 'There is no external integration installed.' => '',
-    // 'You are not allowed to update tasks assigned to someone else.' => '',
-    // 'You are not allowed to change the assignee.' => '',
-    // 'Task suppression is not permitted' => '',
-    // 'Changing assignee is not permitted' => '',
-    // 'Update only assigned tasks is permitted' => '',
-    // 'Only for tasks assigned to the current user' => '',
+    'There is no external integration installed.' => '未安裝外部整合。',
+    'You are not allowed to update tasks assigned to someone else.' => '您不允許更新分配給其他人的任務。',
+    'You are not allowed to change the assignee.' => '您不允許更改被分配人。',
+    'Task suppression is not permitted' => '不允許壓制任務',
+    'Changing assignee is not permitted' => '不允許更改被分配人',
+    'Update only assigned tasks is permitted' => '只允許更新分配的任務',
+    'Only for tasks assigned to the current user' => '僅限於分配給當前使用者的任務',
     'My projects' => '我的專案',
     'You are not a member of any project.' => '你不是任何專案的成員。',
     'My subtasks' => '我的子任務',
     '%d subtasks' => '%d 子任務',
     '%d subtask' => '%d 子任務',
-    // 'Only moving task between those columns is permitted for tasks assigned to the current user' => '',
-    // '[DUPLICATE]' => '',
-    // 'DKK - Danish Krona' => '',
+    'Only moving task between those columns is permitted for tasks assigned to the current user' => '僅允許分配給當前使用者的任務在這些列之間移動',
+    '[DUPLICATE]' => '[重複]',
+    'DKK - Danish Krona' => 'DKK - 丹麥克朗',
     'Remove user from group' => '從群組中移除使用者',
     'Assign the task to its creator' => '將任務分配给建立者',
-    // 'This task was sent by email to "%s" with subject "%s".' => '',
+    'This task was sent by email to "%s" with subject "%s".' => '此任務已通過電子郵件發送給 "%s"，主旨為 "%s"。',
     'Predefined Email Subjects' => '預定義的郵件主旨',
-    // 'Write one subject by line.' => '',
-    // 'Create another link' => '',
-    // 'BRL - Brazilian Real' => '',
-    // 'Add a new Kanboard task' => '',
-    // 'Subtask not started' => '',
-    // 'Subtask currently in progress' => '',
-    // 'Subtask completed' => '',
-    // 'Subtask added successfully.' => '',
-    // '%d subtasks added successfully.' => '',
-    // 'Enter one subtask by line.' => '',
-    // 'Predefined Contents' => '',
-    // 'Predefined contents' => '',
-    // 'Predefined Task Description' => '',
-    // 'Do you really want to remove this template? "%s"' => '',
-    // 'Add predefined task description' => '',
-    // 'Predefined Task Descriptions' => '',
-    // 'Template created successfully.' => '',
-    // 'Unable to create this template.' => '',
-    // 'Template updated successfully.' => '',
-    // 'Unable to update this template.' => '',
-    // 'Template removed successfully.' => '',
-    // 'Unable to remove this template.' => '',
-    // 'Template for the task description' => '',
-    // 'The start date is greater than the end date' => '',
-    // 'Tags must be separated by a comma' => '',
-    // 'Only the task title is required' => '',
-    // 'Creator Username' => '',
-    // 'Color Name' => '',
-    // 'Column Name' => '',
-    // 'Swimlane Name' => '',
-    // 'Time Estimated' => '',
-    // 'Time Spent' => '',
-    // 'External Link' => '',
-    // 'This feature enables the iCal feed, RSS feed and the public board view.' => '',
-    // 'Stop the timer of all subtasks when moving a task to another column' => '',
-    // 'Subtask Title' => '',
-    // 'Add a subtask and activate the timer when moving a task to another column' => '',
-    // 'days' => '',
-    // 'minutes' => '',
-    // 'seconds' => '',
-    // 'Assign automatically a color when preset start date is reached' => '',
-    // 'Move the task to another column once a predefined start date is reached' => '',
-    // 'This task is now linked to the task %s with the relation "%s"' => '',
-    // 'The link with the relation "%s" to the task %s has been removed' => '',
-    // 'Custom Filter:' => '',
-    // 'Unable to find this group.' => '',
-    // '%s moved the task #%d to the column "%s"' => '',
-    // '%s moved the task #%d to the position %d in the column "%s"' => '',
-    // '%s moved the task #%d to the swimlane "%s"' => '',
-    // '%sh spent' => '',
-    // '%sh estimated' => '',
-    // 'Select All' => '',
-    // 'Unselect All' => '',
-    // 'Apply action' => '',
-    // 'Move selected tasks to another column or swimlane' => '',
-    // 'Edit tasks in bulk' => '',
-    // 'Choose the properties that you would like to change for the selected tasks.' => '',
-    // 'Configure this project' => '',
-    // 'Start now' => '',
-    // '%s removed a file from the task #%d' => '',
-    // 'Attachment removed from task #%d: %s' => '',
-    // 'No color' => '',
-    // 'Attachment removed "%s"' => '',
-    // '%s removed a file from the task %s' => '',
-    // 'Move the task to another swimlane when assigned to a user' => '',
-    // 'Destination swimlane' => '',
-    // 'Assign a category when the task is moved to a specific swimlane' => '',
-    // 'Move the task to another swimlane when the category is changed' => '',
-    // 'Reorder this column by priority (ASC)' => '',
-    // 'Reorder this column by priority (DESC)' => '',
-    // 'Reorder this column by assignee and priority (ASC)' => '',
-    // 'Reorder this column by assignee and priority (DESC)' => '',
-    // 'Reorder this column by assignee (A-Z)' => '',
-    // 'Reorder this column by assignee (Z-A)' => '',
-    // 'Reorder this column by due date (ASC)' => '',
-    // 'Reorder this column by due date (DESC)' => '',
-    // 'Reorder this column by id (ASC)' => '',
-    // 'Reorder this column by id (DESC)' => '',
-    // '%s moved the task #%d "%s" to the project "%s"' => '',
-    // 'Task #%d "%s" has been moved to the project "%s"' => '',
-    // 'Move the task to another column when the due date is less than a certain number of days' => '',
-    // 'Automatically update the start date when the task is moved away from a specific column' => '',
-    // 'HTTP Client:' => '',
-    // 'Assigned' => '',
-    // 'Task limits apply to each swimlane individually' => '',
-    // 'Column task limits apply to each swimlane individually' => '',
-    // 'Column task limits are applied to each swimlane individually' => '',
-    // 'Column task limits are applied across swimlanes' => '',
-    // 'Task limit: ' => '',
-    // 'Change to global tag' => '',
-    // 'Do you really want to make the tag "%s" global?' => '',
-    // 'Enable global tags for this project' => '',
-    // 'Group membership(s):' => '',
-    // '%s is a member of the following group(s): %s' => '',
-    // '%d/%d group(s) shown' => '',
-    // 'Subtask creation or modification' => '',
-    // 'Assign the task to a specific user when the task is moved to a specific swimlane' => '',
-    // 'Comment' => '',
-    // 'Collapse vertically' => '',
-    // 'Expand vertically' => '',
-    // 'MXN - Mexican Peso' => '',
-    // 'Estimated vs actual time per column' => '',
-    // 'HUF - Hungarian Forint' => '',
-    // 'XBT - Bitcoin' => '',
-    // 'You must select a file to upload as your avatar!' => '',
-    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
-    // 'Automatically set the due date when the task is moved away from a specific column' => '',
-    // 'No other projects found.' => '',
-    // 'Please choose a project you want to copy the tasks from.' => '',
-    // 'Import Tasks' => '',
-    // 'Copy' => '',
-    // 'Tasks copied successfully.' => '',
-    // 'Unable to copy tasks.' => '',
-    // 'Theme' => '',
-    // 'Theme:' => '',
-    // 'Light theme' => '',
-    // 'Dark theme' => '',
-    // 'Automatic theme - Sync with system' => '',
-    // 'Application managers or more' => '',
-    // 'Administrators' => '',
-    // 'Visibility:' => '',
-    // 'Standard users' => '',
-    // 'Visibility is required' => '',
-    // 'The visibility should be an app role' => '',
-    // 'Reply' => '',
-    // '%s wrote: ' => '',
-    // 'Number of visible tasks in this column and swimlane' => '',
-    // 'Number of tasks in this swimlane' => '',
-    // 'Unable to find another subtask in progress, you can close this window.' => '',
-    // 'This theme is invalid' => '',
-    // 'This role is invalid' => '',
-    // 'This timezone is invalid' => '',
-    // 'This language is invalid' => '',
-    // 'This URL is invalid' => '',
-    // 'Date format invalid' => '',
-    // 'Time format invalid' => '',
-    // 'Invalid Mail transport' => '',
-    // 'Color invalid' => '',
-    // 'This value must be greater or equal to %d' => '',
-    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
-    // 'Just add these tag(s)' => '',
-    // 'Remove internal link(s)' => '',
-);
+    'Write one subject by line.' => '每行寫一個主旨。',
+    'Create another link' => '建立另一個連結',
+    'BRL - Brazilian Real' => 'BRL - 巴西雷亞爾',
+    'Add a new Kanboard task' => '新增 Kanboard 任務',
+    'Subtask not started' => '子任務未開始',
+    'Subtask currently in progress' => '子任務目前正在進行中',
+    'Subtask completed' => '子任務已完成',
+    'Subtask added successfully.' => '子任務已成功新增。',
+    '%d subtasks added successfully.' => '已成功新增 %d 個子任務。',
+    'Enter one subtask by line.' => '每行輸入一個子任務。',
+    'Predefined Contents' => '預定義內容',
+    'Predefined contents' => '預定義內容',
+    'Predefined Task Description' => '預定義任務描述',
+    'Do you really want to remove this template? "%s"' => '您確定要移除此範本嗎？ "%s"',
+    'Add predefined task description' => '新增預定義任務描述',
+    'Predefined Task Descriptions' => '預定義任務描述',
+    'Template created successfully.' => '範本已成功建立。',
+    'Unable to create this template.' => '無法建立此範本。',
+    'Template updated successfully.' => '範本已成功更新。',
+    'Unable to update this template.' => '無法更新此範本。',
+    'Template removed successfully.' => '範本已成功移除。',
+    'Unable to remove this template.' => '無法移除此範本。',
+    'Template for the task description' => '任務描述範本',
+    'The start date is greater than the end date' => '開始日期晚於結束日期',
+    'Tags must be separated by a comma' => '標籤必須用逗號分隔',
+    'Only the task title is required' => '僅任務標題為必填',
+    'Creator Username' => '建立者使用者名稱',
+    'Color Name' => '顏色名稱',
+    'Column Name' => '欄位名稱',
+    'Swimlane Name' => '泳道名稱',
+    'Time Estimated' => '預計時間',
+    'Time Spent' => '花費時間',
+    'External Link' => '外部連結',
+    'This feature enables the iCal feed, RSS feed and the public board view.' => '此功能啟用 iCal feed、RSS feed 和公開看板檢視。',
+    'Stop the timer of all subtasks when moving a task to another column' => '將任務移動到另一列時停止所有子任務的計時器',
+    'Subtask Title' => '子任務標題',
+    'Add a subtask and activate the timer when moving a task to another column' => '新增子任務並在將任務移動到另一列時啟用計時器',
+    'days' => '天',
+    'minutes' => '分鐘',
+    'seconds' => '秒',
+    'Assign automatically a color when preset start date is reached' => '達到預設開始日期時自動分配顏色',
+    'Move the task to another column once a predefined start date is reached' => '達到預定義開始日期後將任務移動到另一列',
+    'This task is now linked to the task %s with the relation "%s"' => '此任務現已使用關係 "%s" 連結到任務 %s',
+    'The link with the relation "%s" to the task %s has been removed' => '與任務 %s 的關係 "%s" 的連結已移除',
+    'Custom Filter:' => '自訂篩選器：',
+    'Unable to find this group.' => '無法找到此群組。',
+    '%s moved the task #%d to the column "%s"' => '%s 將任務 #%d 移動到欄 "%s"',
+    '%s moved the task #%d to the position %d in the column "%s"' => '%s 將任務 #%d 移動到欄 "%s" 的位置 %d',
+    '%s moved the task #%d to the swimlane "%s"' => '%s 將任務 #%d 移動到泳道 "%s"',
+    '%sh spent' => '已花費 %sh',
+    '%sh estimated' => '預計 %sh',
+    'Select All' => '全選',
+    'Unselect All' => '取消全選',
+    'Apply action' => '應用動作',
+    'Move selected tasks to another column or swimlane' => '將選定的任務移動到另一列或泳道',
+    'Edit tasks in bulk' => '批量編輯任務',
+    'Choose the properties that you would like to change for the selected tasks.' => '選擇要變更所選任務的屬性。',
+    'Configure this project' => '設定此專案',
+    'Start now' => '立即開始',
+    '%s removed a file from the task #%d' => '%s 從任務 #%d 移除了檔案',
+    'Attachment removed from task #%d: %s' => '從任務 #%d 移除的附件：%s',
+    'No color' => '無顏色',
+    'Attachment removed "%s"' => '附件 "%s" 已移除',
+    '%s removed a file from the task %s' => '%s 從任務 %s 移除了檔案',
+    'Move the task to another swimlane when assigned to a user' => '將任務分配給使用者時移動到另一個泳道',
+    'Destination swimlane' => '目標泳道',
+    'Assign a category when the task is moved to a specific swimlane' => '當任務移動到特定泳道時分配類別',
+    'Move the task to another swimlane when the category is changed' => '當類別變更時移動任務到另一個泳道',
+    'Reorder this column by priority (ASC)' => '按優先級重排此列 (升序)',
+    'Reorder this column by priority (DESC)' => '按優先級重排此列 (降序)',
+    'Reorder this column by assignee and priority (ASC)' => '按被分配者和優先級重排此列 (升序)',
+    'Reorder this column by assignee and priority (DESC)' => '按被分配者和優先級重排此列 (降序)',
+    'Reorder this column by assignee (A-Z)' => '按被分配者 (A-Z) 重排此列',
+    'Reorder this column by assignee (Z-A)' => '按被分配者 (Z-A) 重排此列',
+    'Reorder this column by due date (ASC)' => '按截止日期重排此列 (升序)',
+    'Reorder this column by due date (DESC)' => '按截止日期重排此列 (降序)',
+    'Reorder this column by id (ASC)' => '按 ID 重排此列 (升序)',
+    'Reorder this column by id (DESC)' => '按 ID 重排此列 (降序)',
+    '%s moved the task #%d "%s" to the project "%s"' => '%s 將任務 #%d "%s" 移動到專案 "%s"',
+    'Task #%d "%s" has been moved to the project "%s"' => '任務 #%d "%s" 已移至專案 "%s"',
+    'Move the task to another column when the due date is less than a certain number of days' => '當截止日期少於特定天數時將任務移動到另一列',
+    'Automatically update the start date when the task is moved away from a specific column' => '當任務從特定欄位移開時，自動更新開始日期',
+    'HTTP Client:' => 'HTTP 客戶端:',
+    'Assigned' => '已分配',
+    'Task limits apply to each swimlane individually' => '任務限制個別應用於每個泳道',
+    'Column task limits apply to each swimlane individually' => '欄位任務限制個別應用於每個泳道',
+    'Column task limits are applied to each swimlane individually' => '欄位任務限制個別應用於每個泳道',
+    'Column task limits are applied across swimlanes' => '欄位任務限制應用於所有泳道',
+    'Task limit: ' => '任務限制：',
+    'Change to global tag' => '變更為全域標籤',
+    'Do you really want to make the tag "%s" global?' => '您確定要將標籤 "%s" 設為全域嗎？',
+    'Enable global tags for this project' => '啟用此專案的全域標籤',
+    'Group membership(s):' => '群組成員：',
+    '%s is a member of the following group(s): %s' => '%s 是以下群組的成員：%s',
+    '%d/%d group(s) shown' => '顯示 %d/%d 個群組',
+    'Subtask creation or modification' => '子任務建立或修改',
+    'Assign the task to a specific user when the task is moved to a specific swimlane' => '將任務移動到特定泳道時，將任務分配給特定使用者',
+    'Comment' => '評論',
+    'Collapse vertically' => '垂直收合',
+    'Expand vertically' => '垂直展開',
+    'MXN - Mexican Peso' => 'MXN - 墨西哥比索',
+    'Estimated vs actual time per column' => '每個欄位的預估時間與實際時間',
+    'HUF - Hungarian Forint' => 'HUF - 匈牙利福林',
+    'XBT - Bitcoin' => 'XBT - 比特幣',
+    'You must select a file to upload as your avatar!' => '您必須選擇要上傳的檔案作為您的頭像！',
+    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '您上傳的檔案不是有效的圖片！ (僅允許 *.gif, *.jpg, *.jpeg 和 *.png)',
+    'Automatically set the due date when the task is moved away from a specific column' => '當任務從特定欄位移開時，自動設定截止日期',
+    'No other projects found.' => '找不到其他專案。',
+    'Tasks copied successfully.' => '任務已成功複製。',
+    'Unable to copy tasks.' => '無法複製任務。',
+    'Theme' => '主題',
+    'Theme:' => '主題：',
+    'Light theme' => '淺色主題',
+    'Dark theme' => '深色主題',
+    'Automatic theme - Sync with system' => '自動主題 - 與系統同步',
+    'Application managers or more' => '應用程式管理員或更高權限',
+    'Administrators' => '管理員',
+    'Visibility:' => '可見性：',
+    'Standard users' => '標準使用者',
+    'Visibility is required' => '可見性是必需的',
+    'The visibility should be an app role' => '可見性應該是應用程式角色',
+    'Reply' => '回覆',
+    '%s wrote: ' => '%s 寫道：',
+    'Number of visible tasks in this column and swimlane' => '此欄位和泳道中可見的任務數量',
+    'Number of tasks in this swimlane' => '此泳道中的任務數量',
+    'Unable to find another subtask in progress, you can close this window.' => '找不到其他正在進行的子任務，您可以關閉此視窗。',
+    'This theme is invalid' => '此主題無效',
+    'This role is invalid' => '此角色無效',
+    'This timezone is invalid' => '此時區無效',
+    'This language is invalid' => '此語言無效',
+    'This URL is invalid' => '此 URL 無效',
+    'Date format invalid' => '日期格式無效',
+    'Time format invalid' => '時間格式無效',
+    'Invalid Mail transport' => '無效的郵件傳輸',
+    'Color invalid' => '顏色無效',
+    'This value must be greater or equal to %d' => '此值必須大於或等於 %d',
+    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '在檔案開頭加入 BOM（Microsoft Excel 需要）',
+    'Just add these tag(s)' => '只需加入這些標籤',
+    'Remove internal link(s)' => '移除內部連結',
+    'Import tasks from another project' => '從其他專案匯入任務',
+    'Select the project to copy tasks from' => '選擇要複製任務的專案',
+    'The total maximum allowed attachments size is %sB.' => '允許的附件總大小上限為 %sB。',
+    'Add attachments' => '加入附件',
+    'Task #%d "%s" is overdue' => '任務 #%d "%s" 已逾期',
+    'Enable notifications by default for all new users' => '預設啟用所有新使用者的通知',
+];
