@@ -8,7 +8,17 @@ use PDO;
 use Kanboard\Core\Security\Token;
 use Kanboard\Core\Security\Role;
 
-const VERSION = 137;
+const VERSION = 139;
+
+function version_139(PDO $pdo)
+{
+    $pdo->exec("ALTER TABLE `comments` ADD COLUMN `visibility` VARCHAR(25) NOT NULL DEFAULT '".Role::APP_USER."'");
+}
+
+function version_138(PDO $pdo)
+{
+    $pdo->exec("ALTER TABLE users ADD COLUMN theme VARCHAR(50) DEFAULT 'light' NOT NULL");
+}
 
 function version_137(PDO $pdo)
 {
@@ -390,7 +400,8 @@ function version_106(PDO $pdo)
 {
     $pdo->exec('RENAME TABLE files TO task_has_files');
 
-    $pdo->exec("
+    $pdo->exec(
+        "
         CREATE TABLE project_has_files (
             `id` INT NOT NULL AUTO_INCREMENT,
             `project_id` INT NOT NULL,
@@ -509,7 +520,7 @@ function version_97(PDO $pdo)
 
         if ($row['is_admin'] == 1) {
             $role = Role::APP_ADMIN;
-        } else if ($row['is_project_admin']) {
+        } elseif ($row['is_project_admin']) {
             $role = Role::APP_MANAGER;
         }
 
@@ -1462,7 +1473,8 @@ function version_19(PDO $pdo)
 
 function version_18(PDO $pdo)
 {
-    $pdo->exec("
+    $pdo->exec(
+        "
         CREATE TABLE task_has_subtasks (
             id INT NOT NULL AUTO_INCREMENT,
             title VARCHAR(255),
@@ -1479,7 +1491,8 @@ function version_18(PDO $pdo)
 
 function version_17(PDO $pdo)
 {
-    $pdo->exec("
+    $pdo->exec(
+        "
         CREATE TABLE task_has_files (
             id INT NOT NULL AUTO_INCREMENT,
             name VARCHAR(50),
@@ -1494,7 +1507,8 @@ function version_17(PDO $pdo)
 
 function version_16(PDO $pdo)
 {
-    $pdo->exec("
+    $pdo->exec(
+        "
         CREATE TABLE project_has_categories (
             id INT NOT NULL AUTO_INCREMENT,
             name VARCHAR(255),
@@ -1527,7 +1541,8 @@ function version_13(PDO $pdo)
 
 function version_12(PDO $pdo)
 {
-    $pdo->exec("
+    $pdo->exec(
+        "
         CREATE TABLE remember_me (
             id INT NOT NULL AUTO_INCREMENT,
             user_id INT,
@@ -1542,7 +1557,8 @@ function version_12(PDO $pdo)
         ) ENGINE=InnoDB CHARSET=utf8"
     );
 
-    $pdo->exec("
+    $pdo->exec(
+        "
         CREATE TABLE last_logins (
             id INT NOT NULL AUTO_INCREMENT,
             auth_type VARCHAR(25),
