@@ -30,7 +30,9 @@
     <?= $this->form->label(t('CSV File'), 'file') ?>
     <?= $this->form->file('file', $errors) ?>
 
+    <?php if ($max_size > 0): ?>
     <p class="form-help"><?= t('Maximum size: ') ?><?= is_integer($max_size) ? $this->text->bytes($max_size) : $max_size ?></p>
+    <?php endif ?>
 
     <?= $this->modal->submitButtons(array('submitLabel' => t('Import'))) ?>
 </form>
