@@ -3,7 +3,7 @@
 define('DB_DRIVER', 'postgres');
 define('DB_USERNAME', 'postgres');
 define('DB_PASSWORD', 'postgres');
-define('DB_HOSTNAME', 'postgres');
+define('DB_HOSTNAME', '127.0.0.1');
 define('DB_NAME', 'kanboard');
 
 define('DEBUG', true);
