@@ -1,5 +1,8 @@
 <?php
 
+namespace KanboardTests\units\Action;
+
+use KanboardTests\units\Base;
 use Kanboard\Action\TaskAssignDueDateOnCreation;
 use Kanboard\EventBuilder\TaskEventBuilder;
 use Kanboard\Model\ProjectModel;
@@ -7,8 +10,6 @@ use Kanboard\Model\TaskCreationModel;
 use Kanboard\Model\TaskFinderModel;
 use Kanboard\Model\TaskModel;
 
-require_once __DIR__.'/../Base.php';
-
 class TaskAssignDueDateOnCreationTest extends Base
 {
     public function testAction()
