@@ -1,7 +1,8 @@
 <?php
 
-require_once __DIR__.'/../Base.php';
+namespace KanboardTests\units\Core;
 
+use KanboardTests\units\Base;
 use Kanboard\Core\Helper;
 
 class HelperTest extends Base
