@@ -1,12 +1,13 @@
 <?php
 
+namespace KanboardTests\units\EventBuilder;
+
+use KanboardTests\units\Base;
 use Kanboard\EventBuilder\CommentEventBuilder;
 use Kanboard\Model\CommentModel;
 use Kanboard\Model\ProjectModel;
 use Kanboard\Model\TaskCreationModel;
 
-require_once __DIR__.'/../Base.php';
-
 class CommentEventBuilderTest extends Base
 {
     public function testWithMissingComment()
