@@ -1,5 +1,8 @@
 <?php
 
+namespace KanboardTests\units\Filter;
+
+use KanboardTests\units\Base;
 use Kanboard\Filter\ProjectActivityTaskIdFilter;
 use Kanboard\Model\ProjectModel;
 use Kanboard\Model\ProjectActivityModel;
@@ -7,8 +10,6 @@ use Kanboard\Model\TaskCreationModel;
 use Kanboard\Model\TaskFinderModel;
 use Kanboard\Model\TaskModel;
 
-require_once __DIR__.'/../Base.php';
-
 class ProjectActivityTaskIdFilterTest extends Base
 {
     public function testFilterByTaskId()
