@@ -1,7 +1,8 @@
 <?php
 
-require_once __DIR__.'/../Base.php';
+namespace KanboardTests\units\Group;
 
+use KanboardTests\units\Base;
 use Kanboard\Group\LdapBackendGroupProvider;
 
 class LdapBackendGroupProviderTest extends Base
