@@ -1,7 +1,8 @@
 <?php
 
-require_once __DIR__.'/../Base.php';
+namespace KanboardTests\units\Model;
 
+use KanboardTests\units\Base;
 use Kanboard\Model\ActionModel;
 use Kanboard\Model\ProjectModel;
 use Kanboard\Model\TaskModel;
