@@ -1,10 +1,11 @@
 <?php
 
+namespace KanboardTests\units\ServiceProvider;
+
+use KanboardTests\units\Base;
 use Kanboard\ServiceProvider\FormatterProvider;
 use Pimple\Container;
 
-require_once __DIR__.'/../Base.php';
-
 class FormatterProviderTest extends Base
 {
     public function testServiceInstance()
