@@ -1,7 +1,8 @@
 <?php
 
-require_once __DIR__.'/../Base.php';
+namespace KanboardTests\units\Validator;
 
+use KanboardTests\units\Base;
 use Kanboard\Validator\GroupValidator;
 
 class GroupValidatorTest extends Base
